@@ -131,7 +131,7 @@ class ZoneName {
         "America/Argentina/Rio_Gallegos", "Argentina", "America/Buenos_Aires",
         "America/Argentina/Salta", "Argentina", "America/Buenos_Aires",
         "America/Argentina/San_Juan", "Argentina", "America/Buenos_Aires",
-        "America/Argentina/San_Luis", "Argentina_Western", "America/Argentina/San_Luis",
+        "America/Argentina/San_Luis", "Argentina", "America/Buenos_Aires",
         "America/Argentina/Tucuman", "Argentina", "America/Buenos_Aires",
         "America/Argentina/Ushuaia", "Argentina", "America/Buenos_Aires",
         "America/Aruba", "Atlantic", "America/Halifax",
@@ -164,7 +164,7 @@ class ZoneName {
         "America/Cuiaba", "Amazon", "America/Manaus",
         "America/Curacao", "Atlantic", "America/Halifax",
         "America/Danmarkshavn", "GMT", "Atlantic/Reykjavik",
-        "America/Dawson", "America_Pacific", "America/Los_Angeles",
+        "America/Dawson", "America_Mountain", "America/Denver",
         "America/Dawson_Creek", "America_Mountain", "America/Denver",
         "America/Denver", "America_Mountain", "America/Denver",
         "America/Detroit", "America_Eastern", "America/New_York",
@@ -236,6 +236,7 @@ class ZoneName {
         "America/North_Dakota/Beulah", "America_Central", "America/Chicago",
         "America/North_Dakota/Center", "America_Central", "America/Chicago",
         "America/North_Dakota/New_Salem", "America_Central", "America/Chicago",
+        "America/Nuuk", "Greenland_Western", "America/Godthab",
         "America/Ojinaga", "America_Mountain", "America/Denver",
         "America/Panama", "America_Eastern", "America/New_York",
         "America/Pangnirtung", "America_Eastern", "America/New_York",
@@ -276,14 +277,14 @@ class ZoneName {
         "America/Tortola", "Atlantic", "America/Halifax",
         "America/Vancouver", "America_Pacific", "America/Los_Angeles",
         "America/Virgin", "Atlantic", "America/Halifax",
-        "America/Whitehorse", "America_Pacific", "America/Los_Angeles",
+        "America/Whitehorse", "America_Mountain", "America/Denver",
         "America/Winnipeg", "America_Central", "America/Chicago",
         "America/Yakutat", "Alaska", "America/Juneau",
         "America/Yellowknife", "America_Mountain", "America/Denver",
-        "Antarctica/Casey", "Australia_Western", "Australia/Perth",
+        "Antarctica/Casey", "Casey", "Antarctica/Casey",
         "Antarctica/Davis", "Davis", "Antarctica/Davis",
         "Antarctica/DumontDUrville", "DumontDUrville", "Antarctica/DumontDUrville",
-        "Antarctica/Macquarie", "Macquarie", "Antarctica/Macquarie",
+        "Antarctica/Macquarie", "Australia_Eastern", "Australia/Sydney",
         "Antarctica/Mawson", "Mawson", "Antarctica/Mawson",
         "Antarctica/McMurdo", "New_Zealand", "Pacific/Auckland",
         "Antarctica/Rothera", "Rothera", "Antarctica/Rothera",
@@ -310,7 +311,7 @@ class ZoneName {
         "Asia/Brunei", "Brunei", "Asia/Brunei",
         "Asia/Calcutta", "India", "Asia/Calcutta",
         "Asia/Chita", "Yakutsk", "Asia/Yakutsk",
-        "Asia/Choibalsan", "Choibalsan", "Asia/Choibalsan",
+        "Asia/Choibalsan", "Mongolia", "Asia/Ulaanbaatar",
         "Asia/Chongqing", "China", "Asia/Shanghai",
         "Asia/Chungking", "China", "Asia/Shanghai",
         "Asia/Colombo", "India", "Asia/Calcutta",
@@ -434,7 +435,7 @@ class ZoneName {
         "Canada/Newfoundland", "Newfoundland", "America/St_Johns",
         "Canada/Pacific", "America_Pacific", "America/Los_Angeles",
         "Canada/Saskatchewan", "America_Central", "America/Chicago",
-        "Canada/Yukon", "America_Pacific", "America/Los_Angeles",
+        "Canada/Yukon", "America_Mountain", "America/Denver",
         "Chile/Continental", "Chile", "America/Santiago",
         "Chile/EasterIsland", "Easter", "Pacific/Easter",
         "Cuba", "Cuba", "America/Havana",
@@ -596,7 +597,6 @@ class ZoneName {
         "US/Michigan", "America_Eastern", "America/New_York",
         "US/Mountain", "America_Mountain", "America/Denver",
         "US/Pacific", "America_Pacific", "America/Los_Angeles",
-        "US/Pacific-New", "America_Pacific", "America/Los_Angeles",
         "US/Samoa", "Samoa", "Pacific/Pago_Pago",
         "W-SU", "Moscow", "Europe/Moscow",
 
@@ -706,6 +706,7 @@ class ZoneName {
         "Europe_Central", "RS", "Europe/Belgrade",
         "Europe_Central", "SE", "Europe/Stockholm",
         "Europe_Central", "SI", "Europe/Ljubljana",
+        "Europe_Central", "SJ", "Arctic/Longyearbyen",
         "Europe_Central", "SK", "Europe/Bratislava",
         "Europe_Central", "SM", "Europe/San_Marino",
         "Europe_Central", "TN", "Africa/Tunis",
@@ -875,6 +876,7 @@ class ZoneName {
         "Atlantic/St_Helena", "Africa/Abidjan",
         "Australia/ACT", "Australia/Sydney",
         "Australia/Canberra", "Australia/Sydney",
+        "Australia/Currie", "Australia/Hobart",
         "Australia/LHI", "Australia/Lord_Howe",
         "Australia/NSW", "Australia/Sydney",
         "Australia/North", "Australia/Darwin",
@@ -978,7 +980,6 @@ class ZoneName {
         "US/Michigan", "America/Detroit",
         "US/Mountain", "America/Denver",
         "US/Pacific", "America/Los_Angeles",
-        "US/Pacific-New", "America/Los_Angeles",
         "US/Samoa", "Pacific/Pago_Pago",
         "UTC", "Etc/UTC",
         "Universal", "Etc/UTC",
