@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2016, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -35,7 +35,9 @@ import java.nio.channels.FileChannel;
 import java.nio.charset.Charset;
 import java.nio.file.OpenOption;
 import java.nio.file.Path;
+import java.security.AccessControlContext;
 import java.security.AccessController;
+import java.security.PrivilegedAction;
 import java.security.PrivilegedActionException;
 import java.security.PrivilegedExceptionAction;
 import java.util.ArrayList;
@@ -125,6 +127,7 @@ public class ResponseSubscribers {
 
         @Override
         public void onSubscribe(Flow.Subscription subscription) {
+            Objects.requireNonNull(subscription);
             if (!subscribed.compareAndSet(false, true)) {
                 subscription.cancel();
             } else {
@@ -135,6 +138,7 @@ public class ResponseSubscribers {
 
         @Override
         public void onNext(List<ByteBuffer> items) {
+            Objects.requireNonNull(items);
             for (ByteBuffer item : items) {
                 byte[] buf = new byte[item.remaining()];
                 item.get(buf);
@@ -145,6 +149,7 @@ public class ResponseSubscribers {
 
         @Override
         public void onError(Throwable throwable) {
+            Objects.requireNonNull(throwable);
             result.completeExceptionally(throwable);
         }
 
@@ -169,9 +174,12 @@ public class ResponseSubscribers {
 
         private final Path file;
         private final OpenOption[] options;
+        private final AccessControlContext acc;
         private final FilePermission[] filePermissions;
+        private final boolean isDefaultFS;
         private final CompletableFuture<Path> result = new MinimalFuture<>();
 
+        private final AtomicBoolean subscribed = new AtomicBoolean();
         private volatile Flow.Subscription subscription;
         private volatile FileChannel out;
 
@@ -188,47 +196,79 @@ public class ResponseSubscribers {
          */
         public static PathSubscriber create(Path file,
                                             List<OpenOption> options) {
-            FilePermission filePermission = null;
             SecurityManager sm = System.getSecurityManager();
+            FilePermission filePermission = null;
             if (sm != null) {
-                String fn = pathForSecurityCheck(file);
-                FilePermission writePermission = new FilePermission(fn, "write");
-                sm.checkPermission(writePermission);
-                filePermission = writePermission;
+                try {
+                    String fn = pathForSecurityCheck(file);
+                    FilePermission writePermission = new FilePermission(fn, "write");
+                    sm.checkPermission(writePermission);
+                    filePermission = writePermission;
+                } catch (UnsupportedOperationException ignored) {
+                    // path not associated with the default file system provider
+                }
             }
-            return new PathSubscriber(file, options, filePermission);
+
+            assert filePermission == null || filePermission.getActions().equals("write");
+            AccessControlContext acc = sm != null ? AccessController.getContext() : null;
+            return new PathSubscriber(file, options, acc, filePermission);
         }
 
         // pp so handler implementations in the same package can construct
         /*package-private*/ PathSubscriber(Path file,
                                            List<OpenOption> options,
+                                           AccessControlContext acc,
                                            FilePermission... filePermissions) {
             this.file = file;
             this.options = options.stream().toArray(OpenOption[]::new);
-            this.filePermissions =
-                    filePermissions == null ? EMPTY_FILE_PERMISSIONS : filePermissions;
+            this.acc = acc;
+            this.filePermissions = filePermissions == null || filePermissions[0] == null
+                            ? EMPTY_FILE_PERMISSIONS : filePermissions;
+            this.isDefaultFS = isDefaultFS(file);
+        }
+
+        private static boolean isDefaultFS(Path file) {
+            try {
+                file.toFile();
+                return true;
+            } catch (UnsupportedOperationException uoe) {
+                return false;
+            }
         }
 
         @Override
         public void onSubscribe(Flow.Subscription subscription) {
+            Objects.requireNonNull(subscription);
+            if (!subscribed.compareAndSet(false, true)) {
+                subscription.cancel();
+                return;
+            }
+
             this.subscription = subscription;
-            if (System.getSecurityManager() == null) {
+            if (acc == null) {
                 try {
                     out = FileChannel.open(file, options);
                 } catch (IOException ioe) {
                     result.completeExceptionally(ioe);
+                    subscription.cancel();
                     return;
                 }
             } else {
                 try {
                     PrivilegedExceptionAction<FileChannel> pa =
                             () -> FileChannel.open(file, options);
-                    out = AccessController.doPrivileged(pa, null, filePermissions);
+                    out = isDefaultFS
+                            ? AccessController.doPrivileged(pa, acc, filePermissions)
+                            : AccessController.doPrivileged(pa, acc);
                 } catch (PrivilegedActionException pae) {
                     Throwable t = pae.getCause() != null ? pae.getCause() : pae;
                     result.completeExceptionally(t);
                     subscription.cancel();
                     return;
+                } catch (Exception e) {
+                    result.completeExceptionally(e);
+                    subscription.cancel();
+                    return;
                 }
             }
             subscription.request(1);
@@ -239,7 +279,7 @@ public class ResponseSubscribers {
             try {
                 out.write(items.toArray(Utils.EMPTY_BB_ARRAY));
             } catch (IOException ex) {
-                Utils.close(out);
+                close();
                 subscription.cancel();
                 result.completeExceptionally(ex);
             }
@@ -249,12 +289,12 @@ public class ResponseSubscribers {
         @Override
         public void onError(Throwable e) {
             result.completeExceptionally(e);
-            Utils.close(out);
+            close();
         }
 
         @Override
         public void onComplete() {
-            Utils.close(out);
+            close();
             result.complete(file);
         }
 
@@ -262,6 +302,22 @@ public class ResponseSubscribers {
         public CompletionStage<Path> getBody() {
             return result;
         }
+
+        private void close() {
+            if (acc == null) {
+                Utils.close(out);
+            } else {
+                PrivilegedAction<Void> pa = () -> {
+                    Utils.close(out);
+                    return null;
+                };
+                if (isDefaultFS) {
+                    AccessController.doPrivileged(pa, acc, filePermissions);
+                } else {
+                    AccessController.doPrivileged(pa, acc);
+                }
+            }
+        }
     }
 
     public static class ByteArraySubscriber<T> implements TrustedSubscriber<T> {
@@ -428,6 +484,10 @@ public class ResponseSubscribers {
 
         @Override
         public int read(byte[] bytes, int off, int len) throws IOException {
+            Objects.checkFromIndexSize(off, len, bytes.length);
+            if (len == 0) {
+                return 0;
+            }
             // get the buffer to read from, possibly blocking if
             // none is available
             ByteBuffer buffer;
@@ -470,6 +530,7 @@ public class ResponseSubscribers {
 
         @Override
         public void onSubscribe(Flow.Subscription s) {
+            Objects.requireNonNull(s);
             try {
                 if (!subscribed.compareAndSet(false, true)) {
                     s.cancel();
@@ -600,6 +661,7 @@ public class ResponseSubscribers {
 
         @Override
         public void onSubscribe(Flow.Subscription subscription) {
+            Objects.requireNonNull(subscription);
             if (!subscribed.compareAndSet(false, true)) {
                 subscription.cancel();
             } else {
@@ -614,6 +676,7 @@ public class ResponseSubscribers {
 
         @Override
         public void onError(Throwable throwable) {
+            Objects.requireNonNull(throwable);
             cf.completeExceptionally(throwable);
         }
 
@@ -907,13 +970,21 @@ public class ResponseSubscribers {
             }
         }
 
+        private final AtomicBoolean subscribed = new AtomicBoolean();
+
         @Override
         public void onSubscribe(Flow.Subscription subscription) {
-            subscriptionCF.complete(subscription);
+            Objects.requireNonNull(subscription);
+            if (!subscribed.compareAndSet(false, true)) {
+                subscription.cancel();
+            } else {
+                subscriptionCF.complete(subscription);
+            }
         }
 
         @Override
         public void onNext(List<ByteBuffer> item) {
+            Objects.requireNonNull(item);
             try {
                 // cannot be called before onSubscribe()
                 assert subscriptionCF.isDone();
@@ -941,6 +1012,7 @@ public class ResponseSubscribers {
             // onError can be called before request(1), and therefore can
             // be called before subscriberRef is set.
             signalError(throwable);
+            Objects.requireNonNull(throwable);
         }
 
         @Override
