@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1998, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1998, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -36,8 +36,10 @@ import java.net.URL;
 import java.net.URLConnection;
 import java.util.HashMap;
 import java.util.Map;
+import java.util.Properties;
 import java.util.TreeMap;
 
+import javax.lang.model.SourceVersion;
 import javax.lang.model.element.Element;
 import javax.lang.model.element.ModuleElement;
 import javax.lang.model.element.PackageElement;
@@ -48,6 +50,7 @@ import javax.tools.DocumentationTool;
 import com.sun.tools.javac.code.Flags;
 import com.sun.tools.javac.code.Symbol.ModuleSymbol;
 import jdk.javadoc.doclet.Reporter;
+import jdk.javadoc.internal.doclets.toolkit.AbstractDoclet;
 import jdk.javadoc.internal.doclets.toolkit.BaseConfiguration;
 import jdk.javadoc.internal.doclets.toolkit.Resources;
 
@@ -62,9 +65,6 @@ import jdk.javadoc.internal.doclets.toolkit.Resources;
  *  If you write code that depends on this, you do so at your own risk.
  *  This code and its internal interfaces are subject to change or
  *  deletion without notice.</b>
- *
- * @author Atul M Dambalkar
- * @author Robert Field
  */
 public class Extern {
 
@@ -92,7 +92,7 @@ public class Extern {
     /**
      * Stores the info for one external doc set
      */
-    private class Item {
+    private static class Item {
 
         /**
          * Element name, found in the "element-list" file in the {@link #path}.
@@ -101,7 +101,7 @@ public class Extern {
 
         /**
          * The URL or the directory path at which the element documentation will be
-         * avaliable.
+         * available.
          */
         final DocPath path;
 
@@ -137,7 +137,7 @@ public class Extern {
 
     public Extern(BaseConfiguration configuration) {
         this.configuration = configuration;
-        this.resources = configuration.getResources();
+        this.resources = configuration.getDocResources();
         this.utils = configuration.utils;
     }
 
@@ -193,7 +193,7 @@ public class Extern {
         DocPath p = fnd.relative ?
                 relativepath.resolve(fnd.path).resolve(filename) :
                 fnd.path.resolve(filename);
-        return new DocLink(p, "is-external=true", memberName);
+        return new DocLink(p, memberName);
     }
 
     /**
@@ -226,6 +226,134 @@ public class Extern {
         return link(url, elemlisturl, reporter, true);
     }
 
+    /**
+     * Check whether links to platform documentation are configured. If not then configure
+     * links using the the documentation URL defined in {@code linkPlatformProperties} or the
+     * default documentation URL if that parameter is {@code null}.
+     *
+     * @param linkPlatformProperties path or URL to properties file containing
+     *                               platform documentation URLs, or null
+     * @param reporter the {@code DocErrorReporter} used to report errors
+     */
+    public void checkPlatformLinks(String linkPlatformProperties, Reporter reporter) {
+        PackageElement javaLang = utils.elementUtils.getPackageElement("java.lang");
+        if (utils.isIncluded(javaLang)) {
+            return;
+        }
+        DocLink link = getExternalLink(javaLang, DocPath.empty, DocPaths.PACKAGE_SUMMARY.getPath());
+        if (link != null) {
+            // Links to platform docs are already configure, nothing to do here.
+            return;
+        }
+        try {
+            int versionNumber = getSourceVersionNumber();
+            String docUrl;
+
+            if (linkPlatformProperties != null) {
+                docUrl = getCustomPlatformDocs(versionNumber, linkPlatformProperties);
+            } else {
+                docUrl = getDefaultPlatformDocs(versionNumber);
+            }
+            if (docUrl == null) {
+                return;
+            }
+            DocPath elementListPath = getPlatformElementList(versionNumber);
+            URL elementListUrl = AbstractDoclet.class.getResource(elementListPath.getPath());
+            if (elementListUrl == null) {
+                reporter.print(Kind.WARNING, resources.getText("doclet.Resource_error", elementListPath.getPath()));
+            } else {
+                try {
+                    readListFromURL(docUrl, elementListUrl);
+                } catch (IOException exc) {
+                    throw new Fault(resources.getText(
+                            "doclet.Resource_error", elementListPath.getPath()), exc);
+                }
+            }
+        } catch (Fault f) {
+            reporter.print(Kind.ERROR, f.getMessage());
+        }
+    }
+
+    /**
+     * Return the resource path for the package or element list for the given {@code version}.
+     * @param version the platform version number
+     * @return the resource path
+     */
+    private DocPath getPlatformElementList(int version) {
+        String filename = version <= 9
+                ? "package-list-" + version + ".txt"
+                : "element-list-" + version + ".txt";
+        return DocPaths.RESOURCES.resolve("releases").resolve(filename);
+    }
+
+    /**
+     * Return the default URL for the platform API documentation for the given {@code version}.
+     * @param version the platform version number
+     * @return the URL as String
+     */
+    private String getDefaultPlatformDocs(int version) {
+        Resources resources = configuration.getDocResources();
+        return version <= 10
+                ? resources.getText("doclet.platform.docs.old", version)
+                : isPrerelease(version)
+                    ? resources.getText("doclet.platform.docs.ea", version)
+                    : resources.getText("doclet.platform.docs.new", version);
+    }
+
+    /**
+     * Retrieve and return the custom URL for the platform API documentation for the given
+     * {@code version} from the properties file at {@code linkPlatformProperties}.
+     * @param version the platform version number
+     * @param linkPlatformProperties path pointing to a properties file
+     * @return the custom URL as String
+     */
+    private String getCustomPlatformDocs(int version, String linkPlatformProperties) throws Fault {
+        String url;
+        try {
+            Properties props = new Properties();
+            InputStream inputStream;
+            if (isUrl(linkPlatformProperties)) {
+                inputStream = toURL(linkPlatformProperties).openStream();
+            } else {
+                inputStream = DocFile.createFileForInput(configuration, linkPlatformProperties).openInputStream();
+            }
+            try (inputStream) {
+                props.load(inputStream);
+            }
+            url = props.getProperty("doclet.platform.docs." + version);
+        } catch (MalformedURLException exc) {
+            throw new Fault(resources.getText("doclet.MalformedURL", linkPlatformProperties), exc);
+        } catch (IOException exc) {
+            throw new Fault(resources.getText("doclet.URL_error", linkPlatformProperties), exc);
+        } catch (DocFileIOException exc) {
+            throw new Fault(resources.getText("doclet.File_error", linkPlatformProperties), exc);
+        }
+        return url;
+    }
+
+    /**
+     * Return the source version number used in the current execution of javadoc.
+     * @return the source version number
+     */
+    private int getSourceVersionNumber() {
+        SourceVersion sourceVersion = configuration.docEnv.getSourceVersion();
+        // TODO it would be nice if this was provided by SourceVersion
+        String versionNumber = sourceVersion.name().substring(8);
+        assert SourceVersion.valueOf("RELEASE_" + versionNumber) == sourceVersion;
+        return Integer.parseInt(versionNumber);
+    }
+
+    /**
+     * Return true if the given {@code sourceVersion} is the same as the current doclet version
+     * and is a pre-release version.
+     * @param sourceVersion the source version number
+     * @return true if it is a pre-release version
+     */
+    private boolean isPrerelease(int sourceVersion) {
+        Runtime.Version docletVersion = configuration.getDocletVersion();
+        return docletVersion.feature() == sourceVersion && docletVersion.pre().isPresent();
+    }
+
     /*
      * Build the extern element list from given URL or the directory path.
      * Flag error if the "-link" or "-linkoffline" option is already used.
@@ -255,11 +383,11 @@ public class Extern {
         }
     }
 
-    private class Fault extends Exception {
+    private static class Fault extends Exception {
         private static final long serialVersionUID = 0;
 
         Fault(String msg, Exception cause) {
-            super(msg, cause);
+            super(msg + (cause == null ? "" : " (" + cause + ")"), cause);
         }
     }
 
@@ -278,12 +406,6 @@ public class Extern {
             ModuleElement moduleElement = utils.containingModule(packageElement);
             Map<String, Item> pkgMap = packageItems.get(utils.getModuleName(moduleElement));
             item = (pkgMap != null) ? pkgMap.get(utils.getPackageName(packageElement)) : null;
-            if (item == null && isAutomaticModule(moduleElement)) {
-                pkgMap = packageItems.get(utils.getModuleName(null));
-                if (pkgMap != null) {
-                    item = pkgMap.get(utils.getPackageName(packageElement));
-                }
-            }
         }
         return item;
     }
@@ -304,13 +426,11 @@ public class Extern {
     private void readElementListFromURL(String urlpath, URL elemlisturlpath) throws Fault {
         try {
             URL link = elemlisturlpath.toURI().resolve(DocPaths.ELEMENT_LIST.getPath()).toURL();
-            try (InputStream in = open(link)) {
-                readElementList(in, urlpath, false);
-            }
+            readListFromURL(urlpath, link);
         } catch (URISyntaxException | MalformedURLException exc) {
             throw new Fault(resources.getText("doclet.MalformedURL", elemlisturlpath.toString()), exc);
         } catch (IOException exc) {
-            readAlternateURL(urlpath, elemlisturlpath);
+            readPackageListFromURL(urlpath, elemlisturlpath);
         }
     }
 
@@ -320,12 +440,10 @@ public class Extern {
      * @param urlpath        Path to the packages.
      * @param elemlisturlpath URL or the path to the "package-list" file.
      */
-    private void readAlternateURL(String urlpath, URL elemlisturlpath) throws Fault {
+    private void readPackageListFromURL(String urlpath, URL elemlisturlpath) throws Fault {
         try {
             URL link = elemlisturlpath.toURI().resolve(DocPaths.PACKAGE_LIST.getPath()).toURL();
-            try (InputStream in = open(link)) {
-                readElementList(in, urlpath, false);
-            }
+            readListFromURL(urlpath, link);
         } catch (URISyntaxException | MalformedURLException exc) {
             throw new Fault(resources.getText("doclet.MalformedURL", elemlisturlpath.toString()), exc);
         } catch (IOException exc) {
@@ -333,6 +451,18 @@ public class Extern {
         }
     }
 
+    /**
+     * Read an element or package list from file.
+     *
+     * @param urlpath URL or path to the packages
+     * @param elementlistpath URL to read "element-list" file from
+     */
+    private void readListFromURL(String urlpath, URL elementlistpath) throws IOException {
+        try (InputStream in = open(elementlistpath)) {
+            readElementList(in, urlpath, false);
+        }
+    }
+
     /**
      * Read the "element-list" file which is available locally.
      *
@@ -387,12 +517,13 @@ public class Extern {
      * @throws IOException if there is a problem reading or closing the stream
      */
     private void readElementList(InputStream input, String path, boolean relative)
-                         throws Fault, IOException {
+                         throws IOException {
         try (BufferedReader in = new BufferedReader(new InputStreamReader(input))) {
             String elemname;
             DocPath elempath;
             String moduleName = null;
             DocPath basePath  = DocPath.create(path);
+            boolean issueWarning = true;
             while ((elemname = in.readLine()) != null) {
                 if (elemname.length() > 0) {
                     elempath = basePath;
@@ -407,34 +538,50 @@ public class Extern {
                         } else {
                             elempath = elempath.resolve(pkgPath);
                         }
-                        checkLinkCompatibility(elemname, moduleName, path);
+                        String actualModuleName = checkLinkCompatibility(elemname, moduleName, path, issueWarning);
                         Item item = new Item(elemname, elempath, relative);
-                        packageItems.computeIfAbsent(moduleName == null ?
-                            DocletConstants.DEFAULT_ELEMENT_NAME : moduleName, k -> new TreeMap<>())
-                            .put(elemname, item);
+                        packageItems.computeIfAbsent(actualModuleName, k -> new TreeMap<>())
+                            .putIfAbsent(elemname, item); // first-one-wins semantics
+                        issueWarning = false;
                     }
                 }
             }
         }
     }
 
-    private void checkLinkCompatibility(String packageName, String moduleName, String path) throws Fault {
+    /**
+     * Check if the external documentation format matches our internal model of the code.
+     * Returns the module name to use for external reference lookup according to the actual
+     * modularity of the external package (and regardless of modularity of documentation).
+     *
+     * @param packageName the package name
+     * @param moduleName the module name or null
+     * @param path the documentation path
+     * @param issueWarning whether to print a warning in case of modularity mismatch
+     * @return the module name to use according to actual modularity of the package
+     */
+    private String checkLinkCompatibility(String packageName, String moduleName, String path, boolean issueWarning)  {
         PackageElement pe = utils.elementUtils.getPackageElement(packageName);
         if (pe != null) {
             ModuleElement me = (ModuleElement)pe.getEnclosingElement();
             if (me == null || me.isUnnamed()) {
-                if (moduleName != null) {
-                    throw new Fault(resources.getText("doclet.linkMismatch_PackagedLinkedtoModule",
-                            path), null);
+                if (moduleName != null && issueWarning) {
+                    configuration.getReporter().print(Kind.WARNING,
+                            resources.getText("doclet.linkMismatch_PackagedLinkedtoModule", path));
                 }
+                // library is not modular, ignore module name even if documentation is modular
+                return DocletConstants.DEFAULT_ELEMENT_NAME;
             } else if (moduleName == null) {
-                // suppress the error message in the case of automatic modules
-                if (!isAutomaticModule(me)) {
-                    throw new Fault(resources.getText("doclet.linkMismatch_ModuleLinkedtoPackage",
-                            path), null);
+                // suppress the warning message in the case of automatic modules
+                if (!isAutomaticModule(me) && issueWarning) {
+                    configuration.getReporter().print(Kind.WARNING,
+                            resources.getText("doclet.linkMismatch_ModuleLinkedtoPackage", path));
                 }
+                // library is modular, use module name for lookup even though documentation is not
+                return utils.getModuleName(me);
             }
         }
+        return moduleName == null ? DocletConstants.DEFAULT_ELEMENT_NAME : moduleName;
     }
 
     // The following should be replaced by a new method such as Elements.isAutomaticModule
