@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2014, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -29,13 +29,19 @@ import java.io.IOException;
 import java.io.PrintWriter;
 import java.io.StringWriter;
 import java.lang.annotation.Annotation;
+import java.lang.reflect.Field;
 import java.lang.reflect.Method;
 import java.lang.reflect.Modifier;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.Enumeration;
+import java.util.HashMap;
+import java.util.HashSet;
 import java.util.List;
+import java.util.Map;
+import java.util.ServiceLoader;
+import java.util.Set;
 import java.util.concurrent.LinkedBlockingQueue;
 import java.util.concurrent.ThreadPoolExecutor;
 import java.util.concurrent.TimeUnit;
@@ -48,13 +54,14 @@ import org.graalvm.compiler.api.replacements.Snippet.ConstantParameter;
 import org.graalvm.compiler.api.replacements.Snippet.NonNullParameter;
 import org.graalvm.compiler.api.replacements.Snippet.VarargsParameter;
 import org.graalvm.compiler.api.test.Graal;
+import org.graalvm.compiler.api.test.ModuleSupport;
 import org.graalvm.compiler.bytecode.BridgeMethodUtils;
 import org.graalvm.compiler.core.CompilerThreadFactory;
 import org.graalvm.compiler.core.common.LIRKind;
 import org.graalvm.compiler.core.common.type.ArithmeticOpTable;
 import org.graalvm.compiler.debug.DebugCloseable;
 import org.graalvm.compiler.debug.DebugContext;
-import org.graalvm.compiler.debug.DebugHandlersFactory;
+import org.graalvm.compiler.debug.DebugContext.Builder;
 import org.graalvm.compiler.debug.GraalError;
 import org.graalvm.compiler.graph.Node;
 import org.graalvm.compiler.graph.NodeClass;
@@ -66,8 +73,13 @@ import org.graalvm.compiler.nodes.StructuredGraph.AllowAssumptions;
 import org.graalvm.compiler.nodes.graphbuilderconf.GraphBuilderConfiguration;
 import org.graalvm.compiler.nodes.graphbuilderconf.GraphBuilderConfiguration.Plugins;
 import org.graalvm.compiler.nodes.graphbuilderconf.InvocationPlugins;
+import org.graalvm.compiler.nodes.java.LoadFieldNode;
 import org.graalvm.compiler.nodes.spi.CoreProviders;
+import org.graalvm.compiler.options.Option;
+import org.graalvm.compiler.options.OptionDescriptor;
+import org.graalvm.compiler.options.OptionDescriptors;
 import org.graalvm.compiler.options.OptionValues;
+import org.graalvm.compiler.options.OptionsParser;
 import org.graalvm.compiler.phases.OptimisticOptimizations;
 import org.graalvm.compiler.phases.PhaseSuite;
 import org.graalvm.compiler.phases.VerifyPhase;
@@ -78,7 +90,6 @@ import org.graalvm.compiler.phases.util.Providers;
 import org.graalvm.compiler.runtime.RuntimeProvider;
 import org.graalvm.compiler.serviceprovider.JavaVersionUtil;
 import org.graalvm.compiler.test.AddExports;
-import org.graalvm.compiler.api.test.ModuleSupport;
 import jdk.internal.vm.compiler.word.LocationIdentity;
 import org.junit.Assert;
 import org.junit.Assume;
@@ -91,6 +102,7 @@ import jdk.vm.ci.meta.JavaField;
 import jdk.vm.ci.meta.JavaMethod;
 import jdk.vm.ci.meta.JavaType;
 import jdk.vm.ci.meta.MetaAccessProvider;
+import jdk.vm.ci.meta.ResolvedJavaField;
 import jdk.vm.ci.meta.ResolvedJavaMethod;
 import jdk.vm.ci.meta.ResolvedJavaType;
 import jdk.vm.ci.meta.Value;
@@ -139,13 +151,23 @@ public class CheckGraalInvariants extends GraalCompilerTest {
         }
 
         protected String getClassPath() {
-            String bootclasspath;
+            String classpath;
             if (JavaVersionUtil.JAVA_SPEC <= 8) {
-                bootclasspath = System.getProperty("sun.boot.class.path");
+                classpath = System.getProperty("sun.boot.class.path");
             } else {
-                bootclasspath = JRT_CLASS_PATH_ENTRY;
+                classpath = JRT_CLASS_PATH_ENTRY;
             }
-            return bootclasspath;
+
+            // Also process classes that go into the libgraal native image.
+            String javaClassPath = System.getProperty("java.class.path");
+            if (javaClassPath != null) {
+                for (String path : javaClassPath.split(File.pathSeparator)) {
+                    if (path.contains("libgraal") && !path.contains("processor")) {
+                        classpath += File.pathSeparator + path;
+                    }
+                }
+            }
+            return classpath;
         }
 
         protected boolean shouldLoadClass(String className) {
@@ -197,10 +219,38 @@ public class CheckGraalInvariants extends GraalCompilerTest {
         @SuppressWarnings("unused")
         protected void updateVerifiers(List<VerifyPhase<CoreProviders>> verifiers) {
         }
+
+        /**
+         * Determines if {@code option} should be checked to ensure it has at least one usage.
+         */
+        public boolean shouldCheckUsage(OptionDescriptor option) {
+            Class<?> declaringClass = option.getDeclaringClass();
+            if (declaringClass.getName().equals("org.graalvm.compiler.truffle.compiler.SharedTruffleCompilerOptions")) {
+                /*
+                 * These options are aliases for Truffle runtime options whose usages are not on the
+                 * class path used when running CheckGraalInvariants.
+                 */
+                return false;
+            }
+            if (declaringClass.getName().equals("org.graalvm.compiler.truffle.compiler.TruffleCompilerOptions")) {
+                /*
+                 * These options are deprecated and will be removed in GraalVM 20.2.0. The
+                 * TruffleIntrinsifyFrameAccess option has no replacement and is unused.
+                 */
+                return false;
+            }
+            if (option.getOptionKey().getClass().isAnonymousClass()) {
+                /*
+                 * Probably a derived option such as
+                 * org.graalvm.compiler.debug.DebugOptions.PrintGraphFile.
+                 */
+                return false;
+            }
+            return true;
+        }
     }
 
     @Test
-    @SuppressWarnings("try")
     public void test() {
         assumeManagementLibraryIsLoadable();
         runTest(new InvariantsTool());
@@ -306,6 +356,8 @@ public class CheckGraalInvariants extends GraalCompilerTest {
         verifiers.add(new VerifyGetOptionsUsage());
         verifiers.add(new VerifyUnsafeAccess());
 
+        loadVerifiers(verifiers);
+
         VerifyFoldableMethods foldableMethodsVerifier = new VerifyFoldableMethods();
         if (tool.shouldVerifyFoldableMethods()) {
             verifiers.add(foldableMethodsVerifier);
@@ -315,7 +367,7 @@ public class CheckGraalInvariants extends GraalCompilerTest {
 
         for (Method m : BadUsageWithEquals.class.getDeclaredMethods()) {
             ResolvedJavaMethod method = metaAccess.lookupJavaMethod(m);
-            try (DebugContext debug = DebugContext.create(options, DebugHandlersFactory.LOADER)) {
+            try (DebugContext debug = new Builder(options).build()) {
                 StructuredGraph graph = new StructuredGraph.Builder(options, debug, AllowAssumptions.YES).method(method).build();
                 try (DebugCloseable s = debug.disableIntercept(); DebugContext.Scope ds = debug.scope("CheckingGraph", graph, method)) {
                     graphBuilderSuite.apply(graph, context);
@@ -330,6 +382,10 @@ public class CheckGraalInvariants extends GraalCompilerTest {
                 }
             }
         }
+
+        Map<ResolvedJavaField, Set<ResolvedJavaMethod>> optionFieldUsages = initOptionFieldUsagesMap(tool, metaAccess, errors);
+        ResolvedJavaType optionDescriptorsType = metaAccess.lookupJavaType(OptionDescriptors.class);
+
         if (errors.isEmpty()) {
             // Order outer classes before the inner classes
             classNames.sort((String a, String b) -> a.compareTo(b));
@@ -365,7 +421,7 @@ public class CheckGraalInvariants extends GraalCompilerTest {
                         String methodName = className + "." + method.getName();
                         if (matches(filters, methodName)) {
                             executor.execute(() -> {
-                                try (DebugContext debug = DebugContext.create(options, DebugHandlersFactory.LOADER)) {
+                                try (DebugContext debug = new Builder(options).build()) {
                                     boolean isSubstitution = method.getAnnotation(Snippet.class) != null || method.getAnnotation(MethodSubstitution.class) != null;
                                     StructuredGraph graph = new StructuredGraph.Builder(options, debug).method(method).setIsSubstitution(isSubstitution).build();
                                     try (DebugCloseable s = debug.disableIntercept(); DebugContext.Scope ds = debug.scope("CheckingGraph", graph, method)) {
@@ -373,6 +429,7 @@ public class CheckGraalInvariants extends GraalCompilerTest {
                                         graphBuilderSuite.apply(graph, context);
                                         // update phi stamps
                                         graph.getNodes().filter(PhiNode.class).forEach(PhiNode::inferStamp);
+                                        collectOptionFieldUsages(optionFieldUsages, optionDescriptorsType, method, graph);
                                         checkGraph(verifiers, context, graph);
                                     } catch (VerificationError e) {
                                         errors.add(e.getMessage());
@@ -411,6 +468,9 @@ public class CheckGraalInvariants extends GraalCompilerTest {
                 }
             }
         }
+
+        checkOptionFieldUsages(errors, optionFieldUsages);
+
         if (!errors.isEmpty()) {
             StringBuilder msg = new StringBuilder();
             String nl = String.format("%n");
@@ -424,8 +484,61 @@ public class CheckGraalInvariants extends GraalCompilerTest {
         }
     }
 
+    @SuppressWarnings("unchecked")
+    private static void loadVerifiers(List<VerifyPhase<CoreProviders>> verifiers) {
+        for (VerifyPhase<CoreProviders> verifier : ServiceLoader.load(VerifyPhase.class)) {
+            verifiers.add(verifier);
+        }
+    }
+
+    /**
+     * Initializes a map from a field annotated by {@link Option} to a set that will be used to
+     * collect methods that accesses the option field.
+     *
+     * @param tool
+     */
+    private static Map<ResolvedJavaField, Set<ResolvedJavaMethod>> initOptionFieldUsagesMap(InvariantsTool tool, MetaAccessProvider metaAccess, List<String> errors) {
+        Map<ResolvedJavaField, Set<ResolvedJavaMethod>> optionFields = new HashMap<>();
+        for (OptionDescriptors set : OptionsParser.getOptionsLoader()) {
+            for (OptionDescriptor option : set) {
+                if (tool.shouldCheckUsage(option)) {
+                    Class<?> declaringClass = option.getDeclaringClass();
+                    try {
+                        Field javaField = declaringClass.getDeclaredField(option.getFieldName());
+                        optionFields.put(metaAccess.lookupJavaField(javaField), new HashSet<>());
+                    } catch (NoSuchFieldException e) {
+                        errors.add(e.toString());
+                    }
+                }
+            }
+        }
+        return optionFields;
+    }
+
+    private static void collectOptionFieldUsages(Map<ResolvedJavaField, Set<ResolvedJavaMethod>> optionFields, ResolvedJavaType optionDescriptorsType, ResolvedJavaMethod method,
+                    StructuredGraph graph) {
+        if (!optionDescriptorsType.isAssignableFrom(method.getDeclaringClass())) {
+            for (LoadFieldNode lfn : graph.getNodes().filter(LoadFieldNode.class)) {
+
+                ResolvedJavaField field = lfn.field();
+                Set<ResolvedJavaMethod> loads = optionFields.get(field);
+                if (loads != null) {
+                    loads.add(graph.method());
+                }
+            }
+        }
+    }
+
+    private static void checkOptionFieldUsages(List<String> errors, Map<ResolvedJavaField, Set<ResolvedJavaMethod>> optionFieldUsages) {
+        for (Map.Entry<ResolvedJavaField, Set<ResolvedJavaMethod>> e : optionFieldUsages.entrySet()) {
+            if (e.getValue().isEmpty()) {
+                errors.add("No uses found for " + e.getKey().format("%H.%n"));
+            }
+        }
+    }
+
     private static boolean isInNativeImage(String className) {
-        return className.startsWith("org.graalvm.nativeimage");
+        return className.startsWith("jdk.internal.vm.compiler.nativeimage");
     }
 
     private static boolean isGSON(String className) {
