@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1996, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1996, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -34,7 +34,6 @@ import java.io.InputStreamReader;
 import java.io.OutputStream;
 import java.math.BigInteger;
 import java.security.*;
-import java.security.spec.AlgorithmParameterSpec;
 import java.security.cert.*;
 import java.security.cert.Certificate;
 import java.util.*;
@@ -128,14 +127,6 @@ public class X509CertImpl extends X509Certificate implements DerEncoder {
     protected AlgorithmId       algId = null;
     protected byte[]            signature = null;
 
-    // recognized extension OIDS
-    private static final String KEY_USAGE_OID = "2.5.29.15";
-    private static final String EXTENDED_KEY_USAGE_OID = "2.5.29.37";
-    private static final String BASIC_CONSTRAINT_OID = "2.5.29.19";
-    private static final String SUBJECT_ALT_NAME_OID = "2.5.29.17";
-    private static final String ISSUER_ALT_NAME_OID = "2.5.29.18";
-    private static final String AUTH_INFO_ACCESS_OID = "1.3.6.1.5.5.7.1.1";
-
     // number of standard key usage bits.
     private static final int NUM_STANDARD_KEY_USAGE = 9;
 
@@ -286,6 +277,9 @@ public class X509CertImpl extends X509Certificate implements DerEncoder {
      * Construct an initialized X509 Certificate. The certificate is stored
      * in raw form and has to be signed to be useful.
      *
+     * The ALGORITHM_ID attribute will be rewritten when signed. The initial
+     * value is ignored.
+     *
      * @param certInfo the X509CertificateInfo which the Certificate is to be
      *             created from.
      */
@@ -518,15 +512,14 @@ public class X509CertImpl extends X509Certificate implements DerEncoder {
      * @param algorithm the name of the signature algorithm used.
      *
      * @exception InvalidKeyException on incorrect key.
-     * @exception NoSuchAlgorithmException on unsupported signature
-     * algorithms.
+     * @exception NoSuchAlgorithmException on unsupported signature algorithms.
      * @exception NoSuchProviderException if there's no default provider.
      * @exception SignatureException on signature errors.
      * @exception CertificateException on encoding errors.
      */
     public void sign(PrivateKey key, String algorithm)
-    throws CertificateException, NoSuchAlgorithmException,
-        InvalidKeyException, NoSuchProviderException, SignatureException {
+            throws CertificateException, NoSuchAlgorithmException,
+            InvalidKeyException, NoSuchProviderException, SignatureException {
         sign(key, algorithm, null);
     }
 
@@ -538,79 +531,32 @@ public class X509CertImpl extends X509Certificate implements DerEncoder {
      *
      * @param key the private key used for signing.
      * @param algorithm the name of the signature algorithm used.
-     * @param provider the name of the provider.
+     * @param provider (optional) the name of the provider.
      *
-     * @exception NoSuchAlgorithmException on unsupported signature
-     * algorithms.
+     * @exception NoSuchAlgorithmException on unsupported signature algorithms.
      * @exception InvalidKeyException on incorrect key.
      * @exception NoSuchProviderException on incorrect provider.
      * @exception SignatureException on signature errors.
      * @exception CertificateException on encoding errors.
      */
     public void sign(PrivateKey key, String algorithm, String provider)
-    throws CertificateException, NoSuchAlgorithmException,
-        InvalidKeyException, NoSuchProviderException, SignatureException {
-        try {
-            sign(key, null, algorithm, provider);
-        } catch (InvalidAlgorithmParameterException e) {
-            // should not happen; re-throw just in case
-            throw new SignatureException(e);
-        }
-    }
-
-    /**
-     * Creates an X.509 certificate, and signs it using the given key
-     * (associating a signature algorithm and an X.500 name), signature
-     * parameters, and security provider. If the given provider name
-     * is null or empty, the implementation look up will be based on
-     * provider configurations.
-     * This operation is used to implement the certificate generation
-     * functionality of a certificate authority.
-     *
-     * @param key the private key used for signing
-     * @param signingParams the parameters used for signing
-     * @param algorithm the name of the signature algorithm used
-     * @param provider the name of the provider, may be null
-     *
-     * @exception NoSuchAlgorithmException on unsupported signature
-     *            algorithms
-     * @exception InvalidKeyException on incorrect key
-     * @exception InvalidAlgorithmParameterException on invalid signature
-     *            parameters
-     * @exception NoSuchProviderException on incorrect provider
-     * @exception SignatureException on signature errors
-     * @exception CertificateException on encoding errors
-     */
-    public void sign(PrivateKey key, AlgorithmParameterSpec signingParams,
-            String algorithm, String provider)
             throws CertificateException, NoSuchAlgorithmException,
-            InvalidKeyException, InvalidAlgorithmParameterException,
-            NoSuchProviderException, SignatureException {
+            InvalidKeyException, NoSuchProviderException, SignatureException {
         try {
             if (readOnly) {
                 throw new CertificateEncodingException(
                         "cannot over-write existing certificate");
             }
-            Signature sigEngine = null;
-            if (provider == null || provider.isEmpty()) {
-                sigEngine = Signature.getInstance(algorithm);
-            } else {
-                sigEngine = Signature.getInstance(algorithm, provider);
-            }
+            Signature sigEngine = SignatureUtil.fromKey(
+                    algorithm, key, provider);
+            algId = SignatureUtil.fromSignature(sigEngine, key);
 
-            SignatureUtil.initSignWithParam(sigEngine, key, signingParams,
-                    null);
-
-            // in case the name is reset
-            if (signingParams != null) {
-                algId = AlgorithmId.get(sigEngine.getParameters());
-            } else {
-                algId = AlgorithmId.get(algorithm);
-            }
             DerOutputStream out = new DerOutputStream();
             DerOutputStream tmp = new DerOutputStream();
 
             // encode certificate info
+            info.set(X509CertInfo.ALGORITHM_ID,
+                    new CertificateAlgorithmId(algId));
             info.encode(tmp);
             byte[] rawCert = tmp.toByteArray();
 
@@ -629,7 +575,7 @@ public class X509CertImpl extends X509Certificate implements DerEncoder {
 
         } catch (IOException e) {
             throw new CertificateEncodingException(e.toString());
-      }
+        }
     }
 
     /**
@@ -909,7 +855,7 @@ public class X509CertImpl extends X509Certificate implements DerEncoder {
             SerialNumber ser = (SerialNumber)info.get(
                               CertificateSerialNumber.NAME + DOT +
                               CertificateSerialNumber.NUMBER);
-           return ser;
+            return ser;
         } catch (Exception e) {
             return null;
         }
@@ -921,6 +867,7 @@ public class X509CertImpl extends X509Certificate implements DerEncoder {
      *
      * @return the subject name.
      */
+    @SuppressWarnings("deprecation")
     public Principal getSubjectDN() {
         if (info == null)
             return null;
@@ -957,6 +904,7 @@ public class X509CertImpl extends X509Certificate implements DerEncoder {
      *
      * @return the issuer name.
      */
+    @SuppressWarnings("deprecation")
     public Principal getIssuerDN() {
         if (info == null)
             return null;
@@ -1423,7 +1371,7 @@ public class X509CertImpl extends X509Certificate implements DerEncoder {
      */
     public byte[] getExtensionValue(String oid) {
         try {
-            ObjectIdentifier findOID = new ObjectIdentifier(oid);
+            ObjectIdentifier findOID = ObjectIdentifier.of(oid);
             String extAlias = OIDMap.getName(findOID);
             Extension certExt = null;
             CertificateExtensions exts = (CertificateExtensions)info.get(
@@ -1526,7 +1474,8 @@ public class X509CertImpl extends X509Certificate implements DerEncoder {
     public static List<String> getExtendedKeyUsage(X509Certificate cert)
         throws CertificateParsingException {
         try {
-            byte[] ext = cert.getExtensionValue(EXTENDED_KEY_USAGE_OID);
+            byte[] ext = cert.getExtensionValue
+                    (KnownOIDs.extendedKeyUsage.value());
             if (ext == null)
                 return null;
             DerValue val = new DerValue(ext);
@@ -1696,7 +1645,8 @@ public class X509CertImpl extends X509Certificate implements DerEncoder {
     public static Collection<List<?>> getSubjectAlternativeNames(X509Certificate cert)
         throws CertificateParsingException {
         try {
-            byte[] ext = cert.getExtensionValue(SUBJECT_ALT_NAME_OID);
+            byte[] ext = cert.getExtensionValue
+                    (KnownOIDs.SubjectAlternativeName.value());
             if (ext == null) {
                 return null;
             }
@@ -1759,7 +1709,8 @@ public class X509CertImpl extends X509Certificate implements DerEncoder {
     public static Collection<List<?>> getIssuerAlternativeNames(X509Certificate cert)
         throws CertificateParsingException {
         try {
-            byte[] ext = cert.getExtensionValue(ISSUER_ALT_NAME_OID);
+            byte[] ext = cert.getExtensionValue
+                    (KnownOIDs.IssuerAlternativeName.value());
             if (ext == null) {
                 return null;
             }
