@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -154,14 +150,44 @@ public class FormatData_fa extends ListResourceBundle {
         final String[] metaValue_AmPmMarkers = new String[] {
                "\u0642\u0628\u0644\u200c\u0627\u0632\u0638\u0647\u0631",
                "\u0628\u0639\u062f\u0627\u0632\u0638\u0647\u0631",
+               "",
+               "",
+               "\u0628\u0627\u0645\u062f\u0627\u062f",
+               "\u0635\u0628\u062d",
+               "\u0638\u0647\u0631",
+               "\u0639\u0635\u0631",
+               "",
+               "",
+               "\u0634\u0628",
+               "\u0646\u06cc\u0645\u0647\u200c\u0634\u0628",
             };
         final String[] metaValue_narrow_AmPmMarkers = new String[] {
                "\u0642",
                "\u0628",
+               "",
+               "",
+               "\u0628",
+               "\u0635",
+               "\u0638",
+               "\u0639",
+               "",
+               "",
+               "\u0634",
+               "\u0646",
             };
         final String[] metaValue_abbreviated_AmPmMarkers = new String[] {
                "\u0642.\u0638.",
                "\u0628.\u0638.",
+               "",
+               "",
+               "\u0628\u0627\u0645\u062f\u0627\u062f",
+               "\u0635\u0628\u062d",
+               "\u0638\u0647\u0631",
+               "\u0639\u0635\u0631",
+               "",
+               "",
+               "\u0634\u0628",
+               "\u0646\u06cc\u0645\u0647\u200c\u0634\u0628",
             };
         final String[] metaValue_TimePatterns = new String[] {
                "H:mm:ss (zzzz)",
@@ -177,30 +203,38 @@ public class FormatData_fa extends ListResourceBundle {
                "EEEE d MMMM y G",
                "d MMMM y G",
                "d MMM y G",
-               "y/M/d G",
+               "y/M/d GGGGG",
             };
         final String[] metaValue_buddhist_DatePatterns = new String[] {
                "EEEE d MMMM y GGGG",
                "d MMMM y GGGG",
                "d MMM y GGGG",
-               "y/M/d GGGG",
+               "y/M/d G",
             };
         final String[] metaValue_java_time_japanese_long_Eras = new String[] {
                "\u0645\u06cc\u0644\u0627\u062f\u06cc",
-               "",
-               "",
-               "",
-               "\u0647\u06cc\u0633\u0647\u200c\u0627\u06cc",
-               "\u0631\u06cc\u0648\u0627",
+               "Meiji",
+               "Taish\u014d",
+               "Sh\u014dwa",
+               "\u0647\u06cc\u0633\u06cc",
+               "Reiwa",
             };
         final String[] metaValue_java_time_japanese_Eras = new String[] {
                "\u0645.",
-               "",
-               "",
-               "",
-               "\u0647\u06cc\u0633\u0647\u200c\u0627\u06cc",
+               "Meiji",
+               "Taish\u014d",
+               "Sh\u014dwa",
+               "\u0647\u06cc\u0633\u06cc",
                "\u0631\u06cc\u0648\u0627",
             };
+        final String[] metaValue_java_time_japanese_narrow_Eras = new String[] {
+               "\u0645",
+               "M",
+               "T",
+               "S",
+               "\u0647\u200d",
+               "\u0631",
+            };
         final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "\u0642\u0628\u0644 \u0627\u0632 R.O.C.",
                "\u062a\u0642\u0648\u06cc\u0645 \u0645\u06cc\u0646\u06af\u0648",
@@ -229,8 +263,15 @@ public class FormatData_fa extends ListResourceBundle {
                "\u0647\u200d.\u0642.",
             };
         final String metaValue_calendarname_gregorian = "\u062a\u0642\u0648\u06cc\u0645 \u0645\u06cc\u0644\u0627\u062f\u06cc";
+        final String[] metaValue_arab_NumberPatterns = new String[] {
+               "#,##0.###",
+               "\u200e\u00a4#,##0.00",
+               "#,##0%",
+               "",
+            };
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
+            { "java.time.japanese.narrow.Eras", metaValue_java_time_japanese_narrow_Eras },
             { "field.year", "\u0633\u0627\u0644" },
             { "calendarname.islamic-umalqura", "\u062a\u0642\u0648\u06cc\u0645 \u0647\u062c\u0631\u06cc \u0642\u0645\u0631\u06cc \u0627\u0645\u200c\u0627\u0644\u0642\u0631\u06cc" },
             { "arabext.NumberElements",
@@ -246,6 +287,8 @@ public class FormatData_fa extends ListResourceBundle {
                     "\u0609",
                     "\u221e",
                     "\u0646\u0627\u0639\u062f\u062f",
+                    "",
+                    "",
                 }
             },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
@@ -255,6 +298,7 @@ public class FormatData_fa extends ListResourceBundle {
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
+            { "japanese.narrow.Eras", metaValue_java_time_japanese_narrow_Eras },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "\u062a\u0642\u0648\u06cc\u0645 \u0647\u062c\u0631\u06cc \u0642\u0645\u0631\u06cc \u062c\u062f\u0648\u0644\u06cc \u0645\u062f\u0646\u06cc" },
             { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -308,6 +352,8 @@ public class FormatData_fa extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "\u0646\u0627\u0639\u062f\u062f",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -317,7 +363,7 @@ public class FormatData_fa extends ListResourceBundle {
             { "japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
             { "field.era", "\u062f\u0648\u0631\u0647" },
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
-            { "field.dayperiod", "\u0642\u0628\u0644/\u0628\u0639\u062f\u0627\u0632\u0638\u0647\u0631" },
+            { "field.dayperiod", "\u0642.\u0638/\u0628.\u0638" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.MonthNames", metaValue_islamic_MonthNames },
             { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
@@ -334,28 +380,49 @@ public class FormatData_fa extends ListResourceBundle {
                     "\u0609",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "calendarname.roc", "\u062a\u0642\u0648\u06cc\u0645 \u062c\u0645\u0647\u0648\u0631\u06cc \u0686\u06cc\u0646 (\u062a\u0627\u06cc\u0648\u0627\u0646)" },
-            { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "islamic.DatePatterns",
+                new String[] {
+                    "EEEE d MMMM y GGGG",
+                    "d MMMM y GGGG",
+                    "d MMM y GGGG",
+                    "y/M/d GGGG",
+                }
+            },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "islamic.Eras", metaValue_java_time_islamic_Eras },
             { "field.month", "\u0645\u0627\u0647" },
+            { "arabext.NumberPatterns", metaValue_arab_NumberPatterns },
             { "java.time.japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
             { "roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.second", "\u062b\u0627\u0646\u06cc\u0647" },
-            { "DayAbbreviations", metaValue_DayNames },
-            { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
+            { "islamic.MonthNarrows",
                 new String[] {
-                    "#,##0.###",
-                    "\u200e\u00a4\u00a0#,##0.00",
-                    "#,##0%",
+                    "\u0645",
+                    "\u0635",
+                    "\u0631",
+                    "\u0631",
+                    "\u062c",
+                    "\u062c",
+                    "\u0631",
+                    "\u0634",
+                    "\u0631",
+                    "\u0634",
+                    "\u0630",
+                    "\u0630",
+                    "",
                 }
             },
+            { "DayAbbreviations", metaValue_DayNames },
+            { "DayNarrows", metaValue_DayNarrows },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u062a\u0642\u0648\u06cc\u0645 \u0647\u062c\u0631\u06cc \u0642\u0645\u0631\u06cc" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
+            { "DayPeriodRules", "night1:19:00-24:00;morning2:04:00-12:00;afternoon1:12:00-13:00;morning1:01:00-04:00;afternoon2:13:00-19:00;night2:00:00-01:00" },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
@@ -366,18 +433,18 @@ public class FormatData_fa extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u0647\u0632\u0627\u0631",
-                    "00 \u0647\u0632\u0627\u0631",
-                    "000 \u0647\u0632\u0627\u0631",
-                    "0 \u0645\u06cc\u0644\u06cc\u0648\u0646",
-                    "00 \u0645\u06cc\u0644\u06cc\u0648\u0646",
-                    "000 \u0645\u06cc\u0644\u06cc\u0648\u0646",
-                    "0 \u0645\u06cc\u0644\u06cc\u0627\u0631\u062f",
-                    "00 \u0645\u06cc\u0644\u06cc\u0627\u0631\u062f",
-                    "000 \u0645\u06cc\u0644\u06cc\u0627\u0631\u062f",
-                    "0 \u0647\u0632\u0627\u0631\u0645\u06cc\u0644\u06cc\u0627\u0631\u062f",
-                    "00 \u0647\u0632\u0627\u0631\u0645\u06cc\u0644\u06cc\u0627\u0631\u062f",
-                    "000 \u0647\u0632\u0627\u0631\u0645\u06cc\u0644\u06cc\u0627\u0631\u062f",
+                    "{one:0' '\u0647\u0632\u0627\u0631 other:0' '\u0647\u0632\u0627\u0631}",
+                    "{one:00' '\u0647\u0632\u0627\u0631 other:00' '\u0647\u0632\u0627\u0631}",
+                    "{one:000' '\u0647\u0632\u0627\u0631 other:000' '\u0647\u0632\u0627\u0631}",
+                    "{one:0' '\u0645\u06cc\u0644\u06cc\u0648\u0646 other:0' '\u0645\u06cc\u0644\u06cc\u0648\u0646}",
+                    "{one:00' '\u0645\u06cc\u0644\u06cc\u0648\u0646 other:00' '\u0645\u06cc\u0644\u06cc\u0648\u0646}",
+                    "{one:000' '\u0645\u06cc\u0644\u06cc\u0648\u0646 other:000' '\u0645\u06cc\u0644\u06cc\u0648\u0646}",
+                    "{one:0' '\u0645\u06cc\u0644\u06cc\u0627\u0631\u062f other:0' '\u0645\u06cc\u0644\u06cc\u0627\u0631\u062f}",
+                    "{one:00' '\u0645\u06cc\u0644\u06cc\u0627\u0631\u062f other:00' '\u0645\u06cc\u0644\u06cc\u0627\u0631\u062f}",
+                    "{one:000' '\u0645\u06cc\u0644\u06cc\u0627\u0631\u062f other:000' '\u0645\u06cc\u0644\u06cc\u0627\u0631\u062f}",
+                    "{one:0' '\u0647\u0632\u0627\u0631\u0645\u06cc\u0644\u06cc\u0627\u0631\u062f other:0' '\u0647\u0632\u0627\u0631\u0645\u06cc\u0644\u06cc\u0627\u0631\u062f}",
+                    "{one:00' '\u0647\u0632\u0627\u0631\u0645\u06cc\u0644\u06cc\u0627\u0631\u062f other:00' '\u0647\u0632\u0627\u0631\u0645\u06cc\u0644\u06cc\u0627\u0631\u062f}",
+                    "{one:000' '\u0647\u0632\u0627\u0631\u0645\u06cc\u0644\u06cc\u0627\u0631\u062f other:000' '\u0647\u0632\u0627\u0631\u0645\u06cc\u0644\u06cc\u0627\u0631\u062f}",
                 }
             },
             { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
@@ -396,6 +463,7 @@ public class FormatData_fa extends ListResourceBundle {
             { "field.zone", "\u0645\u0646\u0637\u0642\u0647\u0654 \u0632\u0645\u0627\u0646\u06cc" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
+            { "arab.NumberPatterns", metaValue_arab_NumberPatterns },
             { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_abbreviated_AmPmMarkers },
             { "Eras",
@@ -409,8 +477,23 @@ public class FormatData_fa extends ListResourceBundle {
             { "QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.abbreviated.AmPmMarkers", metaValue_abbreviated_AmPmMarkers },
             { "standalone.QuarterNarrows", metaValue_QuarterNarrows },
-            { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "java.time.islamic.DatePatterns",
+                new String[] {
+                    "EEEE d MMMM y G",
+                    "d MMMM y G",
+                    "d MMM y G",
+                    "y/M/d G",
+                }
+            },
             { "field.weekday", "\u0631\u0648\u0632 \u0647\u0641\u062a\u0647" },
+            { "islamic.DateTimePatterns",
+                new String[] {
+                    "{1}\u060c \u0633\u0627\u0639\u062a {0}",
+                    "{1}\u060c \u0633\u0627\u0639\u062a {0}",
+                    "",
+                    "",
+                }
+            },
             { "japanese.MonthAbbreviations", metaValue_MonthNames },
             { "islamic.DayAbbreviations", metaValue_DayNames },
             { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
@@ -439,18 +522,18 @@ public class FormatData_fa extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0\u0647\u0632\u0627\u0631",
-                    "00\u00a0\u0647\u0632\u0627\u0631",
-                    "000\u00a0\u0647\u0632\u0627\u0631",
-                    "0\u00a0\u0645\u06cc\u0644\u06cc\u0648\u0646",
-                    "00\u00a0\u0645\u06cc\u0644\u06cc\u0648\u0646",
-                    "000\u00a0\u0645",
-                    "0\u00a0\u0645",
-                    "00\u00a0\u0645",
-                    "000\u00a0\u0645\u06cc\u0644\u06cc\u0627\u0631\u062f",
-                    "0\u00a0\u062a\u0631\u06cc\u0644\u06cc\u0648\u0646",
-                    "00\u00a0\u062a",
-                    "000\u00a0\u062a",
+                    "{one:0\u00a0\u0647\u0632\u0627\u0631 other:0\u00a0\u0647\u0632\u0627\u0631}",
+                    "{one:00\u00a0\u0647\u0632\u0627\u0631 other:00\u00a0\u0647\u0632\u0627\u0631}",
+                    "{one:000\u00a0\u0647\u0632\u0627\u0631 other:000\u00a0\u0647\u0632\u0627\u0631}",
+                    "{one:0\u00a0\u0645\u06cc\u0644\u06cc\u0648\u0646 other:0\u00a0\u0645\u06cc\u0644\u06cc\u0648\u0646}",
+                    "{one:00\u00a0\u0645\u06cc\u0644\u06cc\u0648\u0646 other:00\u00a0\u0645\u06cc\u0644\u06cc\u0648\u0646}",
+                    "{one:000\u00a0\u0645 other:000\u00a0\u0645}",
+                    "{one:0\u00a0\u0645 other:0\u00a0\u0645}",
+                    "{one:00\u00a0\u0645 other:00\u00a0\u0645}",
+                    "{one:000\u00a0\u0628 other:000B}",
+                    "{one:0\u00a0\u062a other:0\u00a0\u062a\u0631\u06cc\u0644\u06cc\u0648\u0646}",
+                    "{one:00\u00a0\u062a other:00\u00a0\u062a}",
+                    "{one:000\u00a0\u062a other:000\u00a0\u062a}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -468,11 +551,20 @@ public class FormatData_fa extends ListResourceBundle {
             { "islamic.TimePatterns", metaValue_TimePatterns },
             { "MonthAbbreviations", metaValue_MonthNames },
             { "standalone.DayNames", metaValue_DayNames },
+            { "PluralRules", "one:i = 0 or n = 1" },
             { "field.hour", "\u0633\u0627\u0639\u062a" },
             { "islamic.MonthAbbreviations", metaValue_islamic_MonthNames },
             { "islamic.narrow.Eras", metaValue_java_time_islamic_Eras },
             { "calendarname.buddhist", "\u062a\u0642\u0648\u06cc\u0645 \u0628\u0648\u062f\u0627\u06cc\u06cc" },
             { "standalone.MonthNames", metaValue_standalone_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u200e\u00a4\u00a0#,##0.00",
+                    "#,##0%",
+                    "\u200e\u00a4\u00a0#,##0.00;\u200e(\u00a4\u00a0#,##0.00)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
