@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -127,6 +123,34 @@ public class FormatData_fa_AF extends ListResourceBundle {
                "\u0631\u06f3",
                "\u0631\u06f4",
             };
+        final String[] metaValue_AmPmMarkers = new String[] {
+               "\u0642\u0628\u0644\u200c\u0627\u0632\u0638\u0647\u0631",
+               "\u0628\u0639\u062f\u0627\u0632\u0638\u0647\u0631",
+               "",
+               "",
+               "\u0628\u0627\u0645\u062f\u0627\u062f",
+               "\u0635\u0628\u062d",
+               "\u0638\u0647\u0631",
+               "\u0628\u0639\u062f\u0627\u0632\u0686\u0627\u0634\u062a",
+               "",
+               "",
+               "\u0634\u0628",
+               "\u0646\u06cc\u0645\u0647\u200c\u0634\u0628",
+            };
+        final String[] metaValue_narrow_AmPmMarkers = new String[] {
+               "\u0642",
+               "\u0628",
+               "",
+               "",
+               "\u0628\u0627\u0645\u062f\u0627\u062f",
+               "\u0635\u0628\u062d",
+               "\u0638\u0647\u0631",
+               "\u0628\u0639\u062f\u0627\u0632\u0686\u0627\u0634\u062a",
+               "",
+               "",
+               "\u0634\u0628",
+               "\u0646\u06cc\u0645\u0647\u200c\u0634\u0628",
+            };
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -148,6 +172,9 @@ public class FormatData_fa_AF extends ListResourceBundle {
                     "",
                 }
             },
+            { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
+            { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
+            { "AmPmMarkers", metaValue_AmPmMarkers },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -162,14 +189,21 @@ public class FormatData_fa_AF extends ListResourceBundle {
             },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.MonthNames", metaValue_MonthNames },
+            { "abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "japanese.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
+            { "buddhist.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "japanese.MonthNames", metaValue_MonthNames },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.QuarterNames", metaValue_QuarterNames },
+            { "roc.AmPmMarkers", metaValue_AmPmMarkers },
+            { "islamic.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "latn.NumberElements",
                 new String[] {
                     ".",
@@ -191,6 +225,7 @@ public class FormatData_fa_AF extends ListResourceBundle {
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.MonthNames", metaValue_MonthNames },
             { "standalone.MonthAbbreviations", metaValue_MonthNames },
+            { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "latn.NumberPatterns",
                 new String[] {
                     "#,##0.###",
@@ -205,6 +240,7 @@ public class FormatData_fa_AF extends ListResourceBundle {
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "japanese.QuarterNames", metaValue_QuarterNames },
+            { "roc.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
         };
         return data;
     }
