@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -154,6 +150,34 @@ public class FormatData_fr extends ListResourceBundle {
                "T3",
                "T4",
             };
+        final String[] metaValue_AmPmMarkers = new String[] {
+               "AM",
+               "PM",
+               "minuit",
+               "midi",
+               "du matin",
+               "",
+               "de l\u2019apr\u00e8s-midi",
+               "",
+               "du soir",
+               "",
+               "du matin",
+               "",
+            };
+        final String[] metaValue_narrow_AmPmMarkers = new String[] {
+               "AM",
+               "PM",
+               "minuit",
+               "midi",
+               "mat.",
+               "",
+               "ap.m.",
+               "",
+               "soir",
+               "",
+               "nuit",
+               "",
+            };
         final String[] metaValue_Eras = new String[] {
                "av. J.-C.",
                "ap. J.-C.",
@@ -170,10 +194,6 @@ public class FormatData_fr extends ListResourceBundle {
                "3",
                "4",
             };
-        final String[] metaValue_buddhist_AmPmMarkers = new String[] {
-               "AM",
-               "PM",
-            };
         final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
                "\u00e8re bouddhique",
@@ -283,6 +303,7 @@ public class FormatData_fr extends ListResourceBundle {
                 }
             },
             { "gonm.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "mtei.NumberElements",
                 new String[] {
                     ".",
@@ -310,10 +331,11 @@ public class FormatData_fr extends ListResourceBundle {
                 new String[] {
                     "{1} '\u00e0' {0}",
                     "{1} '\u00e0' {0}",
-                    "{1} '\u00e0' {0}",
+                    "{1}, {0}",
                     "{1} {0}",
                 }
             },
+            { "narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "latn.NumberElements",
                 new String[] {
                     ",",
@@ -349,7 +371,7 @@ public class FormatData_fr extends ListResourceBundle {
                 }
             },
             { "field.minute", "minute" },
-            { "buddhist.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "bali.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
             { "cham.NumberElements",
@@ -435,6 +457,7 @@ public class FormatData_fr extends ListResourceBundle {
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "calendrier musulman" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
+            { "DayPeriodRules", "midnight:00:00;noon:12:00;night1:00:00-04:00;afternoon1:12:00-18:00;morning1:04:00-12:00;evening1:18:00-24:00" },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "brah.NumberElements", metaValue_brah_NumberElements },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
@@ -481,7 +504,7 @@ public class FormatData_fr extends ListResourceBundle {
                     "",
                 }
             },
-            { "islamic.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "java.NumberElements",
                 new String[] {
@@ -538,7 +561,7 @@ public class FormatData_fr extends ListResourceBundle {
                 }
             },
             { "telu.NumberPatterns", metaValue_arabext_NumberPatterns },
-            { "buddhist.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "kali.NumberElements",
                 new String[] {
                     ".",
@@ -704,13 +727,14 @@ public class FormatData_fr extends ListResourceBundle {
                     "",
                 }
             },
-            { "japanese.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
+            { "AmPmMarkers", metaValue_AmPmMarkers },
             { "timezone.gmtFormat", "UTC{0}" },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "mtei.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
-            { "islamic.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "takr.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "mymr.NumberElements",
                 new String[] {
@@ -750,6 +774,7 @@ public class FormatData_fr extends ListResourceBundle {
                     "",
                 }
             },
+            { "japanese.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "calendarname.japanese", "calendrier japonais" },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_narrow_Eras },
@@ -845,14 +870,14 @@ public class FormatData_fr extends ListResourceBundle {
                 }
             },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_Eras },
-            { "japanese.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "sora.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "long.CompactNumberPatterns",
                 new String[] {
                     "",
                     "",
                     "",
-                    "{one:0' 'millier other:0' 'mille}",
+                    "{1:mille one:0' 'millier other:0' 'mille}",
                     "{one:00' 'mille other:00' 'mille}",
                     "{one:000' 'mille other:000' 'mille}",
                     "{one:0' 'million other:0' 'millions}",
@@ -866,8 +891,8 @@ public class FormatData_fr extends ListResourceBundle {
                     "{one:000' 'billion other:000' 'billions}",
                 }
             },
+            { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
-            { "roc.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "standalone.DayNarrows", metaValue_DayNarrows },
             { "mlym.NumberElements",
@@ -968,10 +993,12 @@ public class FormatData_fr extends ListResourceBundle {
                     "",
                 }
             },
+            { "buddhist.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "Eras", metaValue_Eras },
             { "lepc.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "islamic.QuarterNames", metaValue_QuarterNames },
             { "mymrshan.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "islamic.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "nkoo.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "mong.NumberElements",
                 new String[] {
@@ -1059,7 +1086,7 @@ public class FormatData_fr extends ListResourceBundle {
                     "",
                 }
             },
-            { "roc.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "rohg.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "short.CompactNumberPatterns",
@@ -1083,6 +1110,7 @@ public class FormatData_fr extends ListResourceBundle {
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
             { "cham.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "PluralRules", "one:i = 0,1;many:e = 0 and i != 0 and i % 1000000 = 0 and v = 0 or e != 0..5" },
             { "field.hour", "heure" },
             { "islamic.MonthAbbreviations",
                 new String[] {
@@ -1119,6 +1147,7 @@ public class FormatData_fr extends ListResourceBundle {
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
             { "deva.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "roc.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
         };
         return data;
     }
