@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -157,10 +153,30 @@ public class FormatData_si extends ListResourceBundle {
         final String[] metaValue_AmPmMarkers = new String[] {
                "\u0db4\u0dd9.\u0dc0.",
                "\u0db4.\u0dc0.",
+               "\u0db8\u0dd0\u0daf\u0dd2\u0dba\u0db8",
+               "\u0db8\u0db0\u0dca\u200d\u0dba\u0dcf\u0dc4\u0dca\u0db1\u0dba",
+               "\u0db4\u0dcf\u0db1\u0dca\u0daf\u0dbb",
+               "\u0d8b\u0daf\u0dda",
+               "\u0daf\u0dc0\u0dbd\u0dca",
+               "",
+               "\u0dc4\u0dc0\u0dc3",
+               "",
+               "\u0dbb\u0dd1",
+               "\u0db8\u0dd0\u0daf\u0dd2\u0dba\u0db8\u0da7 \u0db4\u0dc3\u0dd4",
             };
         final String[] metaValue_narrow_AmPmMarkers = new String[] {
                "\u0db4\u0dd9",
                "\u0db4",
+               "\u0db8\u0dd0",
+               "\u0db8",
+               "\u0db4\u0dcf",
+               "\u0d8b",
+               "\u0daf",
+               "",
+               "\u0dc4",
+               "",
+               "\u0dbb\u0dd1",
+               "\u0db8\u0dd0",
             };
         final String[] metaValue_Eras = new String[] {
                "\u0d9a\u0dca\u200d\u0dbb\u0dd2.\u0db4\u0dd6.",
@@ -266,6 +282,7 @@ public class FormatData_si extends ListResourceBundle {
             { "DayNarrows", metaValue_DayNarrows },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0d89\u0dc3\u0dca\u0dbd\u0dcf\u0db8\u0dd3\u0dba \u0daf\u0dd2\u0db1 \u0daf\u0dbb\u0dca\u0dc1\u0db1\u0dba" },
+            { "DayPeriodRules", "midnight:00:00;noon:12:00;night1:18:00-24:00;morning2:06:00-12:00;afternoon1:12:00-14:00;morning1:01:00-06:00;evening1:14:00-18:00;night2:00:00-01:00" },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations",
@@ -376,6 +393,7 @@ public class FormatData_si extends ListResourceBundle {
             { "islamic.TimePatterns", metaValue_TimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
+            { "PluralRules", "one:n = 0,1 or i = 0 and f = 1" },
             { "field.hour", "\u0db4\u0dd0\u0dba" },
             { "calendarname.buddhist", "\u0db6\u0ddc\u0daf\u0dd4 \u0daf\u0dd2\u0db1 \u0daf\u0dbb\u0dca\u0dc1\u0db1\u0dba" },
             { "standalone.MonthNames", metaValue_MonthNames },
