@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -154,19 +150,19 @@ public class FormatData_to extends ListResourceBundle {
                "K3",
                "K4",
             };
-        final String[] metaValue_QuarterNarrows = new String[] {
-               "1",
-               "2",
-               "3",
-               "4",
-            };
         final String[] metaValue_AmPmMarkers = new String[] {
                "hengihengi",
                "efiafi",
-            };
-        final String[] metaValue_narrow_AmPmMarkers = new String[] {
-               "AM",
-               "PM",
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
             };
         final String[] metaValue_Eras = new String[] {
                "KM",
@@ -178,6 +174,26 @@ public class FormatData_to extends ListResourceBundle {
                "h:mm:ss a",
                "h:mm a",
             };
+        final String[] metaValue_buddhist_QuarterNarrows = new String[] {
+               "1",
+               "2",
+               "3",
+               "4",
+            };
+        final String[] metaValue_buddhist_narrow_AmPmMarkers = new String[] {
+               "AM",
+               "PM",
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE d MMMM y G",
                "d MMMM y G",
@@ -209,6 +225,8 @@ public class FormatData_to extends ListResourceBundle {
                "\u2030",
                "\u221e",
                "NaN",
+               "",
+               "",
             };
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
@@ -226,6 +244,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u0609",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
@@ -247,12 +267,14 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "mtei.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "fakamohameti-sivile" },
-            { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "islamic.narrow.AmPmMarkers", metaValue_buddhist_narrow_AmPmMarkers },
             { "takr.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "mymr.NumberElements",
                 new String[] {
@@ -267,6 +289,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.TimePatterns", metaValue_TimePatterns },
@@ -284,6 +308,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "gonm.NumberPatterns", metaValue_arabext_NumberPatterns },
@@ -301,9 +327,10 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
-            { "japanese.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "calendarname.japanese", "fakasiapani" },
             { "mtei.NumberElements",
                 new String[] {
@@ -318,6 +345,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.MonthNames", metaValue_MonthNames },
@@ -336,6 +365,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "long.Eras",
@@ -344,7 +375,7 @@ public class FormatData_to extends ListResourceBundle {
                     "ta\u02bbu \u02bbo S\u012bs\u016b",
                 }
             },
-            { "roc.QuarterNarrows", metaValue_QuarterNarrows },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "saur.NumberElements",
                 new String[] {
                     ".",
@@ -358,6 +389,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "islamic.DayNames", metaValue_DayNames },
@@ -372,7 +405,6 @@ public class FormatData_to extends ListResourceBundle {
                     "{1} {0}",
                 }
             },
-            { "narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "latn.NumberElements",
                 new String[] {
                     ".",
@@ -386,6 +418,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "TF",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -403,6 +437,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "buddhist.DayNames", metaValue_DayNames },
@@ -426,9 +462,11 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
-            { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "saur.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "arab.NumberElements",
                 new String[] {
@@ -443,6 +481,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u0609",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "beng.NumberPatterns", metaValue_arabext_NumberPatterns },
@@ -463,6 +503,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -491,6 +533,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "bali.NumberElements",
@@ -506,9 +550,11 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
-            { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "japanese.narrow.AmPmMarkers", metaValue_buddhist_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "sora.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "brah.NumberElements", metaValue_brah_NumberElements },
@@ -533,8 +579,8 @@ public class FormatData_to extends ListResourceBundle {
                     "{other:000' 'tiliona}",
                 }
             },
-            { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
-            { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
+            { "roc.narrow.AmPmMarkers", metaValue_buddhist_narrow_AmPmMarkers },
             { "standalone.QuarterNames",
                 new String[] {
                     "kuata 1",
@@ -556,6 +602,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
@@ -578,6 +626,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
@@ -594,6 +644,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "java.NumberElements",
@@ -609,6 +661,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "TimePatterns", metaValue_TimePatterns },
@@ -625,6 +679,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "gujr.NumberPatterns", metaValue_arabext_NumberPatterns },
@@ -641,6 +697,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "islamic.DayNarrows", metaValue_DayNarrows },
@@ -659,6 +717,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "field.zone", "taimi fakavahe" },
@@ -684,6 +744,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "sund.NumberElements",
@@ -699,6 +761,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "telu.NumberPatterns", metaValue_arabext_NumberPatterns },
@@ -715,10 +779,11 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
-            { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "buddhist.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "buddhist.narrow.AmPmMarkers", metaValue_buddhist_narrow_AmPmMarkers },
             { "Eras", metaValue_Eras },
             { "hanidec.NumberElements", metaValue_brah_NumberElements },
             { "kali.NumberElements",
@@ -734,14 +799,14 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "roc.DayNames", metaValue_DayNames },
             { "lepc.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "islamic.QuarterNames", metaValue_QuarterNames },
             { "mymrshan.NumberPatterns", metaValue_arabext_NumberPatterns },
-            { "QuarterNarrows", metaValue_QuarterNarrows },
-            { "islamic.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "nkoo.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "mong.NumberElements",
                 new String[] {
@@ -756,6 +821,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "lanatham.NumberPatterns", metaValue_arabext_NumberPatterns },
@@ -784,6 +851,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "mymr.NumberPatterns", metaValue_arabext_NumberPatterns },
@@ -800,6 +869,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "cakm.NumberElements", metaValue_brah_NumberElements },
@@ -817,6 +888,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.DayNames", metaValue_DayNames },
@@ -836,6 +909,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
@@ -857,11 +932,13 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
-            { "islamic.QuarterNarrows", metaValue_QuarterNarrows },
+            { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "limb.NumberElements",
                 new String[] {
                     ".",
@@ -875,6 +952,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "roc.DayNarrows", metaValue_DayNarrows },
@@ -892,6 +971,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
@@ -946,6 +1027,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "calendarname.buddhist", "fakaputa" },
@@ -965,7 +1048,6 @@ public class FormatData_to extends ListResourceBundle {
             { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "deva.NumberPatterns", metaValue_arabext_NumberPatterns },
-            { "roc.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
         return data;
