@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -163,10 +159,30 @@ public class FormatData_tr extends ListResourceBundle {
         final String[] metaValue_AmPmMarkers = new String[] {
                "\u00d6\u00d6",
                "\u00d6S",
+               "gece yar\u0131s\u0131",
+               "\u00f6\u011fle",
+               "sabah",
+               "\u00f6\u011fleden \u00f6nce",
+               "\u00f6\u011fleden sonra",
+               "ak\u015fam\u00fcst\u00fc",
+               "ak\u015fam",
+               "",
+               "gece",
+               "",
             };
         final String[] metaValue_narrow_AmPmMarkers = new String[] {
                "\u00f6\u00f6",
                "\u00f6s",
+               "gece",
+               "\u00f6",
+               "sabah",
+               "\u00f6\u011fleden \u00f6nce",
+               "\u00f6\u011fleden sonra",
+               "ak\u015fam\u00fcst\u00fc",
+               "ak\u015fam",
+               "",
+               "gece",
+               "",
             };
         final String[] metaValue_Eras = new String[] {
                "M\u00d6",
@@ -319,6 +335,7 @@ public class FormatData_tr extends ListResourceBundle {
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "Hicri Takvim" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
+            { "DayPeriodRules", "midnight:00:00;noon:12:00;night1:21:00-06:00;morning2:11:00-12:00;afternoon1:12:00-18:00;morning1:06:00-11:00;afternoon2:18:00-19:00;evening1:19:00-21:00" },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
@@ -424,6 +441,7 @@ public class FormatData_tr extends ListResourceBundle {
             { "islamic.TimePatterns", metaValue_TimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
+            { "PluralRules", "one:n = 1" },
             { "field.hour", "saat" },
             { "islamic.MonthAbbreviations",
                 new String[] {
