@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -258,7 +254,7 @@ public class CurrencyNames_ur extends OpenListResourceBundle {
             { "dzd", "\u0627\u0644\u062c\u06cc\u0631\u06cc\u0627\u0626\u06cc \u062f\u06cc\u0646\u0627\u0631" },
             { "eek", "\u0627\u06cc\u0633\u0679\u0648\u0646\u06cc\u0646 \u06a9\u0631\u0648\u0646" },
             { "egp", "\u0645\u0635\u0631\u06cc \u067e\u0627\u0624\u0646\u0688" },
-            { "ern", "\u0627\u0631\u06cc\u0679\u06cc\u0631\u06cc\u0627 \u06a9\u0627 \u0646\u0627\u0641\u06a9\u0627" },
+            { "ern", "\u0627\u0631\u06cc\u0679\u06cc\u0631\u06cc\u0627\u0626\u06cc \u0646\u0627\u06a9\u0641\u0627" },
             { "etb", "\u0627\u06cc\u062a\u06be\u0648\u067e\u06cc\u0627\u0626\u06cc \u0628\u0650\u0631\u0651" },
             { "eur", "\u06cc\u0648\u0631\u0648" },
             { "fjd", "\u0641\u062c\u06cc \u06a9\u0627 \u0688\u0627\u0644\u0631" },
@@ -345,7 +341,7 @@ public class CurrencyNames_ur extends OpenListResourceBundle {
             { "shp", "\u0633\u06cc\u0646\u0679 \u06c1\u06cc\u0644\u06cc\u0646\u0627 \u067e\u0627\u0624\u0646\u0688" },
             { "sit", "\u0633\u0644\u0648\u0627\u0646\u06cc\u0646 \u0679\u0648\u0644\u0631" },
             { "skk", "\u0633\u0644\u0648\u0648\u06a9 \u06a9\u0631\u0648\u0646\u0627" },
-            { "sll", "\u0633\u06cc\u0626\u0631\u0627 \u0644\u06cc\u0648\u0646 \u0644\u06cc\u0648\u0646" },
+            { "sll", "\u0633\u06cc\u0626\u0631\u0627 \u0644\u06cc\u0648\u0646\u06cc\u0646 \u0644\u06cc\u0648\u0646" },
             { "sos", "\u0635\u0648\u0645\u0627\u0644\u06cc \u0634\u0644\u0646\u06af" },
             { "srd", "\u0633\u0648\u0631\u06cc\u0646\u0627\u0645\u06cc \u0688\u0627\u0644\u0631" },
             { "ssp", "\u062c\u0646\u0648\u0628\u06cc \u0633\u0648\u0688\u0627\u0646\u06cc \u067e\u0627\u0624\u0646\u0688" },
