@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -79,8 +75,9 @@ public class LocaleNames_br extends OpenListResourceBundle {
         final String metaValue_te = "telougou";
         final String metaValue_th = "thai";
         final String metaValue_tl = "tagalog";
-        final String metaValue_frm = "krennc\u02bchalleg";
+        final String metaValue_chr = "cherokee";
         final String metaValue_vai = "vai";
+        final String metaValue_Hans = "eeunaet";
         final Object[][] data = new Object[][] {
             { "ksh", "koluneg" },
             { "Ogam", "ogam" },
@@ -91,6 +88,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "Zsye", "fromlunio\u00f9" },
             { "%%NJIVA", "rannyezh Gniva/Njiva" },
             { "xmf", "megreleg" },
+            { "ccp", "chakmaeg" },
             { "egy", "henegipteg" },
             { "raj", "rajasthani" },
             { "tem", "temne" },
@@ -149,6 +147,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "BY", "Belarus" },
             { "BZ", "Belize" },
             { "type.ca.persian", "deiziadur persek" },
+            { "%%CREISS", "rannyezho\u00f9 Creissent" },
             { "type.nu.hebr", "nivero\u00f9 hebraek" },
             { "CA", "Kanada" },
             { "CC", "Inizi Kokoz" },
@@ -210,7 +209,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "chm", "marieg" },
             { "chp", "chipewyan" },
             { "cho", "choktaw" },
-            { "chr", "cherokee" },
+            { "chr", metaValue_chr },
             { "ER", "Eritrea" },
             { "ES", "Spagn" },
             { "ET", "Etiopia" },
@@ -229,7 +228,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "FO", "Inizi Faero" },
             { "Taml", "tamilek" },
             { "FR", "Fra\u00f1s" },
-            { "%%SIMPLE", "SIMPLE" },
+            { "%%SIMPLE", metaValue_Hans },
             { "pcd", "pikardeg" },
             { "tkl", "tokelau" },
             { "grb", "grebo" },
@@ -266,6 +265,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "GY", "Guyana" },
             { "ckb", "kurdeg sorani" },
             { "zxx", "diyezh" },
+            { "%%VIVARAUP", "vivaroalpeg" },
             { "de_AT", "alamaneg Aostria" },
             { "Vaii", metaValue_vai },
             { "HK", "Hong Kong RMD Sina" },
@@ -302,7 +302,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "Zmth", "notadur jedoniel" },
             { "type.nu.thai", "sifro\u00f9 thai" },
             { "vro", "voroeg" },
-            { "%%POSIX", "POSIX" },
+            { "%%POSIX", "stlenneg" },
             { "type.nu.beng", "sifro\u00f9 bengali" },
             { "type.nu.cyrl", "nivero\u00f9 kirillek" },
             { "JE", "Jerzenez" },
@@ -311,10 +311,10 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "JM", "Jamaika" },
             { "%%EKAVSK", "serbeg gant distagadur ekavian" },
             { "JO", "Jordania" },
-            { "%%1606NICT", metaValue_frm },
             { "JP", "Japan" },
+            { "%%1606NICT", "krennc\u02bchalleg diwezha\u00f1" },
             { "ain", "ainoueg" },
-            { "%%KOCIEWIE", "Kociewie" },
+            { "%%KOCIEWIE", "rannyezh polonek Kociewie" },
             { "guz", "gusiieg" },
             { "tog", "nyasa tonga" },
             { "type.nu.knda", "sifro\u00f9 kanarek" },
@@ -328,6 +328,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "KM", "Komorez" },
             { "KN", "Saint Kitts ha Nevis" },
             { "Knda", "kannada" },
+            { "Zinh", "h\u00earezh" },
             { "fr_CA", "galleg Kanada" },
             { "KP", "Korea an Norzh" },
             { "KR", "Korea ar Su" },
@@ -374,7 +375,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "MH", "Inizi Marshall" },
             { "ale", "aleouteg" },
             { "type.nu.vaii", "sifro\u00f9 vai" },
-            { "MK", "Makedonia" },
+            { "MK", "Makedonia an Norzh" },
             { "ML", "Mali" },
             { "MM", "Myanmar (Birmania)" },
             { "MN", "Mongolia" },
@@ -395,6 +396,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "MY", "Malaysia" },
             { "MZ", "Mozambik" },
             { "NA", "Namibia" },
+            { "%%ARANES", "araneg" },
             { "202", "Afrika issaharat" },
             { "type.ca.hebrew", "deiziadur hebraek" },
             { "type.co.dictionary", "urzh rumma\u00f1 ar geriadur" },
@@ -412,6 +414,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "NP", "Nepal" },
             { "NR", "Nauru" },
             { "NU", "Niue" },
+            { "Phnx", "fenikianek" },
             { "rof", "rombo" },
             { "tsi", "tsimshian" },
             { "NZ", "Zeland-Nevez" },
@@ -419,6 +422,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "rom", "romanieg" },
             { "crh", "turkeg Krimea" },
             { "ang", "hensaozneg" },
+            { "%%GRMISTR", "skritur okitanek mistralek" },
             { "OM", "Oman" },
             { "%%PETR1708", "reizhskrivadur rusianek 1708 P\u00ear I" },
             { "anp", "angika" },
@@ -433,6 +437,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "PG", "Papoua Ginea-Nevez" },
             { "PH", "Filipinez" },
             { "PK", "Pakistan" },
+            { "%%NICARD", "nisardeg" },
             { "PL", "Polonia" },
             { "ewo", "ewondo" },
             { "PM", "Sant-P\u00ear-ha-Mikelon" },
@@ -490,6 +495,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "015", "Afrika an Norzh" },
             { "SG", "Singapour" },
             { "SH", "Saint-Helena" },
+            { "type.lb.strict", "stil torr linenn strizh" },
             { "017", "Afrika ar C\u02bchreiz" },
             { "SI", "Slovenia" },
             { "018", "Afrika ar Su" },
@@ -513,7 +519,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "SX", "Sint Maarten" },
             { "SY", "Siria" },
             { "yao", "yao" },
-            { "SZ", "Swaziland" },
+            { "SZ", "Eswatini" },
             { "arw", "arawakeg" },
             { "arz", "arabeg Egipt" },
             { "ary", "arabeg Maroko" },
@@ -566,7 +572,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "US", "Stado\u00f9-Unanet" },
             { "haw", "hawaieg" },
             { "%%1959ACAD", "belaruseg akademek" },
-            { "%%IVANCHOV", "reizhskrivadur Ivanchov" },
+            { "%%IVANCHOV", "reizhskrivadur bulgarek Ivanchov" },
             { "type.co.gb2312han", "urzh rumma\u00f1 sinaek eeunaet - GB2312" },
             { "UY", "Uruguay" },
             { "prg", "henbruseg" },
@@ -581,6 +587,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "VE", "Venezuela" },
             { "VG", "Inizi Gwerc\u02bch Breizh-Veur" },
             { "VI", "Inizi Gwerc\u02bch ar Stado\u00f9-Unanet" },
+            { "%%LEMOSIN", "rannyezh Limousin" },
             { "VN", "Vi\u00eat Nam" },
             { "VU", "Vanuatu" },
             { "nog", "nogay" },
@@ -601,7 +608,9 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "type.nu.mtei", "sifro\u00f9 meitei mayek" },
             { "wal", "walamo" },
             { "was", "washo" },
+            { "XA", "pouez-mouezh gaou" },
             { "war", "waray" },
+            { "XB", "BiDi gaou" },
             { "awa", "awadhi" },
             { "061", "Polinezia" },
             { "%%KSCOR", "kerneveureg standart" },
@@ -609,6 +618,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "type.nu.brah", "sifro\u00f9 brahmi" },
             { "Gujr", metaValue_gu },
             { "Zxxx", "anskrivet" },
+            { "Batk", "batak" },
             { "YE", "Yemen" },
             { "nqo", "nkoeg" },
             { "type.co.standard", "urzh rumma\u00f1 standart" },
@@ -622,6 +632,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "%%NEWFOUND", "saozneg an Douar-Nevez" },
             { "ZA", "Suafrika" },
             { "type.nu.sund", "sifro\u00f9 sundanek" },
+            { "type.lb.loose", "stil torr linenn lezober" },
             { "Deva", "devanagari" },
             { "type.nu.geor", "nivero\u00f9 jorjianek" },
             { "type.co.zhuyin", "urzh rumma\u00f1 Zhuyin" },
@@ -638,7 +649,9 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "type.nu.telu", "sifro\u00f9 telougou" },
             { "lou", "kreoleg Louiziana" },
             { "loz", "lozi" },
+            { "%%FONKIRSH", "lizherenneg fonetek Kirshenbaum" },
             { "%%ASANTE", "achanti" },
+            { "%%AUVERN", "arverneg" },
             { "jmc", "machame" },
             { "type.nu.hansfin", "nivero\u00f9 sinaek eeunaet an arc\u02bchant" },
             { "hil", "hiligaynon" },
@@ -655,7 +668,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "nwc", "newari klasel" },
             { "udm", "oudmourteg" },
             { "Khmr", metaValue_km },
-            { "%%FONNAPA", "FONNAPA" },
+            { "%%FONNAPA", "lizherenneg fonetek Norzh Amerika" },
             { "type.ca.islamic-rgsa", "deiziadur islamek (Arabia Saoudat)" },
             { "sad", "sandawe" },
             { "type.nu.roman", "nivero\u00f9 roman" },
@@ -673,6 +686,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "%%BISCAYAN", "rannyezh euskarek Bizkaia" },
             { "sbp", "sangu" },
             { "lui", "luiseno" },
+            { "%%GRITAL", "skritur okitanek Italia" },
             { "nyn", "nyankole" },
             { "nym", "nyamwezi" },
             { "lun", "lunda" },
@@ -685,6 +699,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "bal", "baloutchi" },
             { "ban", "balineg" },
             { "uga", "ougariteg" },
+            { "type.nu.wara", "sifro\u00f9 warang" },
             { "fit", "finneg trao\u00f1ienn an Torne" },
             { "luy", "luyia" },
             { "bar", "bavarieg" },
@@ -712,6 +727,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "av", "avar" },
             { "ay", "aymara" },
             { "az", "azerbaidjaneg" },
+            { "%%CISAUP", "kizalpeg" },
             { "%%OSOJS", "rannyezh Oseacco/Osojane" },
             { "%%UNIFON", "lizherenneg fonetek Unifon" },
             { "ba", "bachkir" },
@@ -761,6 +777,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "dje", "zarma" },
             { "type.nu.grek", "nivero\u00f9 gresianek" },
             { "ee", "ewe" },
+            { "type.lb.normal", "stil torr linenn boas" },
             { "ro_MD", "moldoveg" },
             { "el", "gresianeg" },
             { "en", "saozneg" },
@@ -774,11 +791,11 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "Samr", "samaritek" },
             { "shi", "tacheliteg" },
             { "hsb", "uhelsorabeg" },
-            { "Hani", "han" },
+            { "Hani", "sinalunio\u00f9 (han)" },
             { "%%ULSTER", "rannyezh skotek Ulad" },
             { "shn", "shan" },
             { "fa", "perseg" },
-            { "Hans", "eeunaet" },
+            { "Hans", metaValue_Hans },
             { "type.nu.latn", "sifro\u00f9 arabek ar C\u02bchorn\u00f4g" },
             { "Hant", "hengounel" },
             { "ff", "fula" },
@@ -825,9 +842,10 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "id", "indonezeg" },
             { "type.nu.tibt", "sifro\u00f9 tibetan" },
             { "ie", "interlingue" },
+            { "%%GASCON", "gwaskoneg" },
             { "ig", "igbo" },
-            { "frm", metaValue_frm },
             { "ii", "yieg Sichuan" },
+            { "frm", "krennc\u02bchalleg" },
             { "%%RUMGR", "roma\u00f1cheg Grischun" },
             { "%%AO1990", "emglev 1990 war ar reizhskrivadur portugalek" },
             { "ik", "inupiaq" },
@@ -917,6 +935,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "nl", "nederlandeg" },
             { "nn", "norvegeg nynorsk" },
             { "no", "norvegeg" },
+            { "%%PROVENC", "prova\u00f1seg" },
             { "nr", "ndebele ar Su" },
             { "nv", "navac\u02bcho" },
             { "kaa", "karakalpak" },
@@ -988,11 +1007,12 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "ru", "rusianeg" },
             { "bss", "akoose" },
             { "rw", "kinyarwanda" },
-            { "zbl", "Bliss" },
+            { "zbl", "arouezio\u00f9 Bliss" },
             { "kea", "kabuverdianu" },
             { "mic", "mikmakeg" },
             { "suk", "sukuma" },
             { "en_AU", "saozneg Aostralia" },
+            { "Dupl", "berrskriverezh Duploy\u00e9" },
             { "sa", "sanskriteg" },
             { "%%UCCOR", "kerneveureg unvan" },
             { "sc", "sardeg" },
@@ -1014,12 +1034,14 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "sr", "serbeg" },
             { "ListKeyTypePattern", "{0} : {1}" },
             { "ss", "swati" },
+            { "type.cf.account", "furmad unanenn jedi\u00f1" },
             { "st", "sotho ar Su" },
             { "Java", "javanek" },
             { "su", "sundaneg" },
             { "%%NEDIS", "rannyezh Natisone" },
             { "sv", "svedeg" },
             { "sw", "swahili" },
+            { "type.nu.wcho", "sifro\u00f9 wantcho" },
             { "type.nu.hantfin", "nivero\u00f9 sinaek hengounel an arc\u02bchant" },
             { "ibb", "ibibio" },
             { "iba", "iban" },
@@ -1031,7 +1053,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "145", "Azia ar C\u02bchorn\u00f4g" },
             { "tg", "tadjik" },
             { "th", metaValue_th },
-            { "%%SPANGLIS", "SPANGLIS" },
+            { "%%SPANGLIS", "spanglish" },
             { "ti", "tigrigna" },
             { "bug", "bugi" },
             { "kfo", "koroeg" },
@@ -1045,6 +1067,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "tr", "turkeg" },
             { "ts", "tsonga" },
             { "swb", "komoreg" },
+            { "Cakm", "chakmaek" },
             { "tt", "tatar" },
             { "%%XSISTEMO", "esperanteg sistem X" },
             { "dyu", "dyula" },
@@ -1093,6 +1116,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "wo", "wolof" },
             { "zgh", "tamacheg Maroko standart" },
             { "ar_001", "arabeg modern" },
+            { "Cans", "silabennaoueg engenidik unvan Kanada" },
             { "%%FONXSAMP", "treuzskrivadur X-SAMPA" },
             { "gay", "gayo" },
             { "Mong", "mongolek" },
@@ -1127,12 +1151,15 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "kln", "kalendjineg" },
             { "zh", "sinaeg" },
             { "Bopo", "bopomofo" },
+            { "key.lb", "stil torr linenn" },
             { "zu", "zouloueg" },
             { "type.co.phonebook", "urzh rumma\u00f1 al levr-pellgomz" },
             { "%%MONOTON", "gresianeg untonel" },
             { "Geor", "jorjianek" },
+            { "%%LENGADOC", "lengadokeg" },
             { "kmb", "kimbundu" },
             { "type.nu.jpanfin", "nivero\u00f9 japanek an arc\u02bchant" },
+            { "Cham", "cham" },
             { "gez", "gezeg" },
             { "mrj", "marieg ar C\u02bchorn\u00f4g" },
             { "Syrn", "siriek ar Reter" },
@@ -1150,21 +1177,24 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "%%1901", "reizhskrivadur alamanek hengounel" },
             { "kos", "kosrae" },
             { "vec", "venezieg" },
-            { "%%PAHAWH2", "PAHAWH2" },
-            { "%%PAHAWH3", "PAHAWH3" },
-            { "%%PAHAWH4", "PAHAWH4" },
+            { "%%PAHAWH2", "reizhskrivadur pahawh hmong lankad 2" },
+            { "%%PAHAWH3", "reizhskrivadur pahawh hmong lankad 3" },
+            { "%%PAHAWH4", "reizhskrivadur pahawh hmong doare diwezha\u00f1" },
             { "type.nu.limb", "sifro\u00f9 limbu" },
             { "zh_Hant", "sinaeg hengounel" },
             { "Sund", "sundanek" },
             { "vep", "vepseg" },
             { "kpe", "kpelle" },
+            { "%%GRCLASS", "skritur okitanek klasel" },
             { "type.nu.khmr", "sifro\u00f9 khmer" },
             { "ilo", "ilokanoeg" },
             { "%%VALENCIA", "valensianeg" },
+            { "Cprt", "silabennaoueg kipriek" },
             { "%%BAKU1926", "lizherenneg latin turkek unvan" },
             { "%%IJEKAVSK", "serbeg gant distagadur ijekavian" },
             { "mua", "moundangeg" },
             { "type.nu.guru", "sifro\u00f9 gurmukhi" },
+            { "%%BORNHOLM", "rannyezh Bornholm" },
             { "mul", "yezho\u00f9 lies" },
             { "%%PUTER", "rannyezh roma\u00f1chek Puter" },
             { "cad", "caddo" },
@@ -1173,11 +1203,13 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "Glag", "glagolitek" },
             { "gil", "gilberteg" },
             { "%%KKCOR", "kerneveureg kumun" },
+            { "Cher", metaValue_chr },
             { "car", "karibeg" },
             { "type.nu.tamldec", "sifro\u00f9 tamilek" },
             { "krc", "karatchay-balkar" },
             { "inh", "ingoucheg" },
             { "kri", "krio" },
+            { "fa_AF", "dareg" },
             { "krl", "karelieg" },
             { "%%OXENDICT", "skritur Oxford English Dictionary" },
             { "efi", "efik" },
