@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -95,6 +91,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
         final String metaValue_si = "Sinhala";
         final String metaValue_te = "Telugu";
         final String metaValue_tl = "Tagalog";
+        final String metaValue_ccp = "Chakma";
         final String metaValue_chr = "Cherokee";
         final String metaValue_cop = "Coptais";
         final String metaValue_gez = "Ge\u2019ez";
@@ -121,6 +118,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "Tagb", "Tagbanwa" },
             { "Zsye", "Emoji" },
             { "%%NJIVA", "Dual-chainnt Gniva/Njiva" },
+            { "ccp", metaValue_ccp },
             { "egy", "\u00c8ipheitis \u00c0rsaidh" },
             { "raj", "Rajasthani" },
             { "Phag", "Phags-pa" },
@@ -189,8 +187,10 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "BY", "A\u2019 Bhealaruis" },
             { "BZ", "A\u2019 Bheil\u00ecs" },
             { "type.ca.persian", "Am M\u00ecosachan Pearsach" },
+            { "%%CREISS", "Ogsatanais Chroissant" },
             { "type.nu.hebr", "\u00c0ireamhan na h-Eabhra" },
             { "CA", "Canada" },
+            { "Kits", "Litrichean beaga na Khitan" },
             { "CC", "Na h-Eileanan Chocos (Keeling)" },
             { "mzn", "Mazanderani" },
             { "CD", "Congo - Kinshasa" },
@@ -283,7 +283,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "Taml", "Taimil" },
             { "FR", "An Fhraing" },
             { "Kpel", metaValue_kpe },
-            { "%%SIMPLE", "SIMPLE" },
+            { "%%SIMPLE", "Samhlaidhean s\u00ecmplichte" },
             { "pcd", "Picard" },
             { "tkl", metaValue_TK },
             { "grb", "Grebo" },
@@ -325,6 +325,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "zxx", "Susbaint nach eil \u2019na ch\u00e0nan" },
             { "Jurc", "Jurchen" },
             { "tly", "Talysh" },
+            { "%%VIVARAUP", "Ogsatanais Vivaro-Ailpeach" },
             { "pdt", "Plautdietsch" },
             { "de_AT", "Gearmailtis na h-Ostaire" },
             { "Vaii", metaValue_vai },
@@ -412,12 +413,13 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "phn", "Phenicis" },
             { "Cyrs", "Cirilis Seann-Sl\u00e0bhais na h-Eaglaise" },
             { "gwi", "Gwich\u02bcin" },
-            { "%%LUNA1918", "LUNA1918" },
+            { "%%LUNA1918", "Litreachadh na Ruisise \u00e0s d\u00e8idh 1917" },
             { "nds", "Gearmailtis \u00ccochdarach" },
             { "LI", "Lichtenstein" },
             { "LK", "Sri Lanca" },
             { "akk", "Acadais" },
             { "cop", metaValue_cop },
+            { "Hmnp", "Nyiakeng Puachue Hmong" },
             { "LR", "Lib\u00e8ir" },
             { "esu", "Yupik Mheadhanach" },
             { "LS", "Leasoto" },
@@ -459,6 +461,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "MQ", "Mairtinic" },
             { "MR", "Morat\u00e0inea" },
             { "MS", "Montsarat" },
+            { "Chrs", "Khwarazm" },
             { "MT", "Malta" },
             { "cps", "Capiznon" },
             { "type.m0.ungegn", "Tar-litreachadh GEGN nan D\u00f9thchannan Aonaichte" },
@@ -472,6 +475,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "MZ", "M\u00f2saimbic" },
             { "Phli", "Pahlavi nan snaidh-sgr\u00ecobhaidhean" },
             { "NA", "An Namaib" },
+            { "%%ARANES", "Aranais" },
             { "202", "Afraga Deas air an t-Sathara" },
             { "type.ca.hebrew", "Am M\u00ecosachan Eabhrach" },
             { "type.co.dictionary", "\u00d2rdugh se\u00f2rsachaidh an fhaclair" },
@@ -501,10 +505,12 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "Mero", "Meroiticeach" },
             { "crh", "Turcais Chriomach" },
             { "ang", "Seann-Bheurla" },
+            { "%%GRMISTR", "N\u00f2s-sgr\u00ecobhaidh Mhistral na h-Ogsatanaise" },
             { "OM", "Om\u00e0n" },
             { "%%PETR1708", "Litreachadh Pheadair 1708" },
             { "anp", "Angika" },
             { "crs", "Seiseallais" },
+            { "type.nu.hmnp", "\u00c0ireamhan Nyiakeng Puachue" },
             { "Xpeo", metaValue_peo },
             { "type.nu.hmng", "\u00c0ireamhan Pahawh Hmong" },
             { "PA", "Panama" },
@@ -517,6 +523,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "PG", "Gini Nuadh Phaputhach" },
             { "PH", "Na h-Eileanan Filipineach" },
             { "PK", "Pagast\u00e0n" },
+            { "%%NICARD", "Ogsatanais Nice" },
             { "PL", "A\u2019 Ph\u00f2lainn" },
             { "ewo", "Ewondo" },
             { "PM", "Saint Pierre agus Miquelon" },
@@ -556,6 +563,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "jbo", "Lojban" },
             { "Rjng", "Rejang" },
             { "009", "Roinn a\u2019 Chuain S\u00e8imh" },
+            { "Elym", "Elymaidheach" },
             { "%%SURSILV", "Sursilvan" },
             { "RO", "Rom\u00e0inia" },
             { "RS", "An t-S\u00e8irb" },
@@ -588,7 +596,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "SI", "An t-Sl\u00f2bhain" },
             { "type.nu.mymrtlng", "\u00c0ireamhan Tai Laing Mi\u00e0nmar" },
             { "018", "Ceann a Deas Afraga" },
-            { "SJ", "Svalbard agus Jan Mayen" },
+            { "SJ", "Svalbard is Jan Mayen" },
             { "019", "An D\u00e0 Aimeireaga" },
             { "SK", "An t-Sl\u00f2bhac" },
             { "Bamu", "Bamum" },
@@ -609,7 +617,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "SX", "Sint Maarten" },
             { "SY", "Siridhea" },
             { "yao", "Yao" },
-            { "SZ", "D\u00f9thaich nan Suasaidh" },
+            { "SZ", "eSwatini" },
             { "arw", "Arawak" },
             { "arz", "Arabais \u00c8ipheiteach" },
             { "ary", "Arabais Mhorocach" },
@@ -621,6 +629,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "TC", "Na h-Eileanan Turcach is Caiceo" },
             { "yav", "Yangben" },
             { "TD", "An t-Se\u00e0d" },
+            { "Qaag", "Zawgyi" },
             { "TF", "Ranntairean a Deas na Frainge" },
             { "ase", "Cainnt-shanais na h-Aimeireaga" },
             { "TG", "Togo" },
@@ -667,7 +676,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "US", "Na St\u00e0itean Aonaichte" },
             { "haw", "C\u00e0nan Hawai\u2019i" },
             { "%%1959ACAD", "Bealaruisis Acadamaigeach" },
-            { "%%IVANCHOV", "IVANCHOV" },
+            { "%%IVANCHOV", "Bulgarian in 1899 orthography = Bulgairis le litreachadh na bliadhna 1899" },
             { "type.co.gb2312han", "\u00d2rdugh se\u00f2rsachaidh na S\u00ecnise Simplichte - GB2312" },
             { "UY", "Uruguaidh" },
             { "prg", "Pruisis" },
@@ -678,10 +687,11 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "VA", "Cathair na Bhatacain" },
             { "pro", "Seann-Phroven\u00e7al" },
             { "VC", "Naomh Bhionsant agus Eileanan Greanadach" },
-            { "%%HSISTEMO", "HSISTEMO" },
+            { "%%HSISTEMO", "Roghainn-\u00e8iginn stannardach litreachadh na h-Esperanto le h" },
             { "VE", "A\u2019 Bheiniseala" },
             { "VG", "Eileanan Breatannach na Maighdinn" },
             { "VI", "Eileanan na Maighdinn aig na SA" },
+            { "%%LEMOSIN", "Ogsatanais Lemosin" },
             { "Soyo", "Soyombo" },
             { "VN", "Bhiet-Nam" },
             { "VU", "Vanuatu" },
@@ -707,7 +717,9 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "type.nu.mtei", "\u00c0ireamhan Meetei Mayek" },
             { "wal", "Wolaytta" },
             { "was", "Washo" },
+            { "XA", "Sr\u00e0can fuadain" },
             { "war", "Waray" },
+            { "XB", "D\u00e0-chomhaireach fuadain" },
             { "awa", "Awadhi" },
             { "061", "Poilin\u00e8is" },
             { "%%KSCOR", "Litreachadh stannardach" },
@@ -752,8 +764,10 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "type.nu.telu", "\u00c0ireamhan Telugu" },
             { "lou", "Cr\u00ectheol Louisiana" },
             { "loz", "Lozi" },
+            { "%%FONKIRSH", "C\u00f2dachadh Kirshenbaum na h-Aibidil Fuaim-e\u00f2laiche" },
             { "Nkgb", "Naxi Geba" },
-            { "%%ASANTE", "ASANTE" },
+            { "%%ASANTE", "Asante" },
+            { "%%AUVERN", "Auvernhat" },
             { "jmc", "Machame" },
             { "hif", "Hindis Fh\u00ecditheach" },
             { "type.nu.hansfin", "\u00c0ireamhan ionmhasail na S\u00ecnise Shimplichte" },
@@ -772,7 +786,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "nwc", "Newari Chlasaigeach" },
             { "udm", "Udmurt" },
             { "Khmr", metaValue_km },
-            { "%%FONNAPA", "FONNAPA" },
+            { "%%FONNAPA", "Aibidil Fhuaim-e\u00f2lach Aimeireaga a Tuath" },
             { "type.ca.islamic-rgsa", "Am M\u00ecosachan Ioslamach (Ar\u00e0ibia nan Sabhd, sealladh)" },
             { "Limb", "Limbu" },
             { "sad", "Sandawe" },
@@ -792,12 +806,14 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "sba", "Ngambay" },
             { "Guru", "Gurmukhi" },
             { "%%ALUKU", "Dual-chainnt Aluku" },
+            { "type.nu.diak", "\u00c0ireamhan Dives Akuru" },
             { "lua", "Luba-Lulua" },
             { "%%BISCAYAN", "Dual-chainnt Bizkaia" },
             { "type.nu.tirh", "\u00c0ireamhan Tirhuta" },
             { "type.d0.fwidth", "L\u00e0n-Leud" },
             { "sbp", "Sangu" },
             { "lui", "Luise\u00f1o" },
+            { "%%GRITAL", "N\u00f2s-sgr\u00ecobhaidh Eadailteach na h-Ogsatanaise" },
             { "nyn", "Nyankole" },
             { "nym", "Nyamwezi" },
             { "lun", "Lunda" },
@@ -823,6 +839,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "scn", "Sisilis" },
             { "aa", "Afar" },
             { "ab", "Abchasais" },
+            { "Aran", "Nastaliq" },
             { "bbc", "Batak Toba" },
             { "ae", metaValue_ae },
             { "af", "Afraganais" },
@@ -846,6 +863,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "az", "Asarbaide\u00e0nais" },
             { "Rohg", "Hanifi Rohingya" },
             { "Khoj", "Khojki" },
+            { "%%CISAUP", "Ogsatanais cios-Ailpeach" },
             { "%%OSOJS", "Dual-chainnt Oseacco/Osojane" },
             { "%%UNIFON", "Aibidil fuaim-e\u00f2lais Unifon" },
             { "ba", "Bashkir" },
@@ -942,10 +960,11 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "type.m0.bgn", "Tar-litreachadh BGN nan St\u00e0itean Aonaichte" },
             { "umb", "Umbundu" },
             { "fr", "Fraingis" },
-            { "%%AKUAPEM", "AKUAPEM" },
+            { "%%AKUAPEM", "Akuapem" },
             { "sid", "Sidamo" },
             { "fy", "Fr\u00ecoslannais Shiarach" },
             { "ga", "Gaeilge" },
+            { "Wcho", "Wancho" },
             { "gd", "G\u00e0idhlig" },
             { "Gong", "Gunjala Gondi" },
             { "gl", "Gail\u00ecsis" },
@@ -963,7 +982,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "hi", "Hindis" },
             { "hup", "Hupa" },
             { "bik", "Bikol" },
-            { "bin", "Bini" },
+            { "bin", "Edo" },
             { "ho", "Hiri Motu" },
             { "hr", "Cr\u00f2thaisis" },
             { "ht", "Cr\u00ectheol Haidhti" },
@@ -977,6 +996,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "id", "Innd-Innsis" },
             { "type.nu.tibt", "\u00c0ireamhan na Tibeitise" },
             { "ie", "Interlingue" },
+            { "%%GASCON", "Ogsatanais Ghascogne" },
             { "ig", "Igbo" },
             { "ii", "Yi Sichuan" },
             { "frm", "Meadhan-Fhraingis" },
@@ -1082,6 +1102,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "nl", "Duitsis" },
             { "nn", "Nynorsk na Nirribhidh" },
             { "no", "Nirribhis" },
+            { "%%PROVENC", "Ogsatanais Phrovence" },
             { "nr", "Ndebele Dheasach" },
             { "type.nu.modi", "\u00c0ireamhan Modi" },
             { "Osge", metaValue_osa },
@@ -1199,6 +1220,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "%%NEDIS", "Dual-chainnt Natisone" },
             { "sv", "Suainis" },
             { "sw", "Kiswahili" },
+            { "type.nu.wcho", "\u00c0ireamhan Wancho" },
             { "type.nu.hantfin", "\u00c0ireamhan ionmhasail na S\u00ecnise Thradaiseanta" },
             { "ibb", "Ibibio" },
             { "iba", "Iban" },
@@ -1223,11 +1245,11 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "dyo", "Jola-Fonyi" },
             { "type.nu.jpan", "\u00c0ireamhan na Seapanaise" },
             { "tr", "Turcais" },
+            { "Cakm", metaValue_ccp },
             { "ts", "Tsonga" },
             { "swb", "Comorais" },
-            { "Cakm", "Chakma" },
             { "tt", "Tatarais" },
-            { "%%XSISTEMO", "XSISTEMO" },
+            { "%%XSISTEMO", "Roghainn-\u00e8iginn stannardach litreachadh na h-Esperanto le x" },
             { "dyu", "Dyula" },
             { "tw", "Twi" },
             { "ty", "C\u00e0nan Tahiti" },
@@ -1287,7 +1309,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "zgh", "Tamazight Stannardach Moroco" },
             { "ar_001", "Nuadh-Arabais Stannardach" },
             { "Cans", "Sgr\u00ecobhadh Lideach Aonaichte nan T\u00f9sanach Canadach" },
-            { "%%FONXSAMP", "FONXSAMP" },
+            { "%%FONXSAMP", "Tar-sgr\u00ecobhadh X-SAMPA" },
             { "gay", "Gayo" },
             { "Mong", metaValue_mn },
             { "mnc", "Manchu" },
@@ -1297,6 +1319,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "mni", "Manipuri" },
             { "Latn", metaValue_la },
             { "Latg", "Laideann Gh\u00e0idhealach" },
+            { "Nand", "Nandinagari" },
             { "type.nu.hans", "\u00c0ireamhan na S\u00ecnise Shimplichte" },
             { "type.nu.hant", "\u00c0ireamhan na S\u00ecnise Thradaiseanta" },
             { "xh", "Xhosa" },
@@ -1333,6 +1356,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "%%MONOTON", "Greugais mhonotonach" },
             { "Geor", metaValue_ka },
             { "Shrd", "Sharada" },
+            { "%%LENGADOC", "Ogsatanais Lengadoc" },
             { "kmb", "Kimbundu" },
             { "type.nu.jpanfin", "\u00c0ireamhan ionmhasail na Seapanaise" },
             { "Cham", "Cham" },
@@ -1345,6 +1369,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "type.nu.olck", "\u00c0ireamhan Ol Chiki" },
             { "type.co.reformed", "\u00d2rdugh se\u00f2rsachaidh ath-leasaichte" },
             { "Tglg", metaValue_tl },
+            { "Yezi", "Yezidis" },
             { "%%ITIHASA", "Itihasa" },
             { "Palm", "Palmyrene" },
             { "ebu", "Embu" },
@@ -1362,15 +1387,18 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "Sund", "Sunda" },
             { "vep", "Veps" },
             { "kpe", metaValue_kpe },
+            { "%%GRCLASS", "N\u00f2s-sgr\u00ecobhaidh clasaigeach na h-Ogsatanaise" },
             { "type.nu.khmr", "\u00c0ireamhan Cm\u00e8ar" },
             { "Tirh", "Tirhuta" },
             { "ilo", "Iloko" },
             { "%%VALENCIA", "Valenci\u00e0" },
             { "Cprt", "C\u00ecoprasais" },
+            { "Diak", "Dives Akuru" },
             { "%%BAKU1926", "Abidil Laideann aonaichte na Turcaise" },
             { "%%IJEKAVSK", "S\u00e8irbis le fuaimneachadh Ijekavia" },
             { "mua", "Mundang" },
             { "type.nu.guru", "\u00c0ireamhan Gurmukhi" },
+            { "%%BORNHOLM", "Bornholmsk" },
             { "mul", "Iomadh c\u00e0nan" },
             { "%%PUTER", "Puter" },
             { "cad", "Caddo" },
@@ -1387,6 +1415,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "inh", "Ingush" },
             { "krj", "Kinaray-a" },
             { "kri", "Krio" },
+            { "fa_AF", "Dari" },
             { "krl", "Cairealais" },
             { "%%OXENDICT", "Litreachadh faclair Oxford na Beurla" },
             { "efi", "Efik" },
