@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -197,6 +193,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "%%CREISS", "croissant-occitanska" },
             { "type.nu.hebr", "hebreiska taltecken" },
             { "CA", "Kanada" },
+            { "Kits", "khitanska" },
             { "CC", "Kokos\u00f6arna" },
             { "mzn", "mazanderani" },
             { "CD", "Kongo-Kinshasa" },
@@ -277,7 +274,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "EU", "Europeiska unionen" },
             { "elx", "elamitiska" },
             { "type.ca.gregorian", "gregoriansk kalender" },
-            { "EZ", "eurozonen" },
+            { "EZ", "euroomr\u00e5det" },
             { "chy", "cheyenne" },
             { "type.nu.gujr", "gujaratiska siffror" },
             { "Inds", "indus" },
@@ -305,7 +302,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "tkr", "tsakhur" },
             { "vot", "votiska" },
             { "GB", "Storbritannien" },
-            { "pcm", "Nigeria-pidgin" },
+            { "pcm", "nigeriansk pidgin" },
             { "GD", "Grenada" },
             { "GE", "Georgien" },
             { "GF", "Franska Guyana" },
@@ -339,7 +336,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "pdt", "mennonitisk l\u00e5gtyska" },
             { "de_AT", "\u00f6sterrikisk tyska" },
             { "Vaii", metaValue_vai },
-            { "HK", "Hongkong" },
+            { "HK", "Hongkong SAR" },
             { "HM", "Heard\u00f6n och McDonald\u00f6arna" },
             { "HN", "Honduras" },
             { "HR", "Kroatien" },
@@ -470,12 +467,13 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "MM", "Myanmar (Burma)" },
             { "new", metaValue_new },
             { "MN", "Mongoliet" },
-            { "MO", "Macao" },
+            { "MO", "Macao SAR" },
             { "aln", "gegiska" },
             { "MP", "Nordmarianerna" },
             { "MQ", "Martinique" },
             { "MR", "Mauretanien" },
             { "MS", "Montserrat" },
+            { "Chrs", "khwarezmiska" },
             { "MT", "Malta" },
             { "cps", "kapisnon" },
             { "type.m0.ungegn", "enligt FN:s geografiska namnkommitt\u00e9" },
@@ -643,7 +641,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "TA", "Tristan da Cunha" },
             { "asa", "asu" },
             { "type.ms.ussystem", "USA:s m\u00e5ttsystem" },
-            { "021", "norra Amerika" },
+            { "021", "Norra Amerika" },
             { "TC", "Turks- och Caicos\u00f6arna" },
             { "yav", "yangben" },
             { "TD", "Tchad" },
@@ -654,7 +652,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "TH", "Thailand" },
             { "TJ", "Tadzjikistan" },
             { "029", "Karibien" },
-            { "TK", "Tokelau" },
+            { "TK", "Tokelau\u00f6arna" },
             { "TL", "\u00d6sttimor" },
             { "ybb", "bamilek\u00e9-jemba" },
             { "type.co.searchjl", "s\u00f6ksorteringsordning f\u00f6r att s\u00f6ka p\u00e5 inledande Hangul-konsonant" },
@@ -777,7 +775,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "ZW", "Zimbabwe" },
             { "ZZ", "ok\u00e4nd region" },
             { "Runr", "runor" },
-            { "type.ms.metric", "SI-enheter" },
+            { "type.ms.metric", "metersystem" },
             { "type.ca.iso8601", "ISO 8601-kalender" },
             { "lol", "mongo" },
             { "nso", "nordsotho" },
@@ -828,6 +826,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "sba", "ngambay" },
             { "Guru", "gurmukhiska" },
             { "%%ALUKU", "Aluku-dialekt" },
+            { "type.nu.diak", "dives akuru-siffror" },
             { "lua", "luba-lulua" },
             { "%%BISCAYAN", "Biscaya-dialekt" },
             { "type.nu.tirh", "tirhuta-siffror" },
@@ -910,7 +909,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "Nkoo", metaValue_nqo },
             { "sel", "selkup" },
             { "ca", "katalanska" },
-            { "ses", "Gao-songhai" },
+            { "ses", "songhai" },
             { "ce", "tjetjenska" },
             { "ch", "chamorro" },
             { "%%REVISED", "reformerad stavning" },
@@ -970,9 +969,9 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "shn", "shan" },
             { "Hano", "hanun\u00f3\u2019o" },
             { "fa", "persiska" },
-            { "Hans", "f\u00f6renklade" },
+            { "Hans", "f\u00f6renklad" },
             { "type.nu.latn", "v\u00e4sterl\u00e4ndska siffror" },
-            { "Hant", "traditionella" },
+            { "Hant", "traditionell" },
             { "ff", "fulani" },
             { "shu", "Tchad-arabiska" },
             { "hsn", "xiang" },
@@ -1403,6 +1402,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "Tglg", metaValue_tl },
             { "Egyd", "demotiska" },
             { "Egyh", "hieratiska" },
+            { "Yezi", "yazidiska" },
             { "%%ITIHASA", "itihasa-dialekt" },
             { "Palm", "palmyreniska" },
             { "ebu", "embu" },
@@ -1429,10 +1429,12 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "ilo", "iloko" },
             { "%%VALENCIA", "valensisk dialekt" },
             { "Cprt", "cypriotiska" },
+            { "Diak", "dives akuru" },
             { "%%BAKU1926", "1926 \u00e5rs stavning" },
             { "%%IJEKAVSK", "ijekavisk dialekt" },
             { "mua", "mundang" },
             { "type.nu.guru", "gurmukhiska siffror" },
+            { "%%BORNHOLM", "Bornholm" },
             { "mul", "flera spr\u00e5k" },
             { "%%PUTER", "puter-dialekt" },
             { "cad", "caddo" },
